//
//  Goal.m
//  MoveCoachMobile
//
//  Created by Joel Russell on 9/18/13.
//

#import "Goal.h"

@implementation Goal

@synthesize date, goal1, goal2, modified, calendarEventIdentifier, expectedGoalCompletionDate;

- (id)init
{
    return [self initWithGoal1Text:@""];
}

- (id)initWithGoal1Text:(NSString *)goal1Text
{
    return [self initWithGoal1Text:goal1Text andGoal2Text:@"" andDate:[NSDate date]];
}

- (id)initWithGoal1Text:(NSString *)goal1Text andGoal2Text:(NSString *)goal2Text andDate:(NSDate *)aDate
{
    self = [super init];
    
    if (self) {
        
        self.goal1 = goal1Text;
        self.goal2 = goal2Text;
        self.date =  aDate;
    }
    
    return self;
}

- (id)initWithGoal:(Goal *)aGoal
{
    self = [super init];
     
    if (self) {
        self.date = [NSDate date];
        self.goal1 = aGoal.goal1;
        self.goal2 = aGoal.goal2;
    }
    
    return self;
}

- (id) initWithCoder:(NSCoder *)aDecoder {
    self = [super init];
    
    if (self) {
        
        [self setDate:[aDecoder decodeObjectForKey:@"date"]];
        [self setGoal1:[aDecoder decodeObjectForKey:@"goal1"]];
        [self setGoal2:[aDecoder decodeObjectForKey:@"goal2"]];
        [self setCalendarEventIdentifier:[aDecoder decodeObjectForKey:@"calendarEventIdentifier"]];
        [self setExpectedGoalCompletionDate:[aDecoder decodeObjectForKey:@"expectedGoalCompletionDate"]];
        
    }
    return self;
}

- (void) encodeWithCoder:(NSCoder *)aCoder {
    
    [aCoder encodeObject:date forKey:@"date"];
    [aCoder encodeObject:goal1 forKey:@"goal1"];
    [aCoder encodeObject:goal2 forKey:@"goal2"];
    [aCoder encodeObject:calendarEventIdentifier forKey:@"calendarEventIdentifier"];
    [aCoder encodeObject:expectedGoalCompletionDate forKey:@"expectedGoalCompletionDate"];
}

- (BOOL)isArchivable
{
    NSTimeInterval goalAge = fabs([self.date timeIntervalSinceNow]);
        
    if (goalAge > ARCHIVE_THRESHOLD) {
        return YES;
    } else {
        return NO;
    }
}

-(void)setGoal1:(NSString *)aGoal1
{
    if ((goal1 != nil) && ![goal1 isEqualToString: @""] && ![aGoal1 isEqualToString: @""] && ![aGoal1 isEqualToString: goal1]) {
        self.modified = YES;
    }
    goal1 = aGoal1;
}

-(void)setGoal2:(NSString *)aGoal2
{
    if ((goal2 != nil) && ![goal2 isEqualToString: @""] && ![aGoal2 isEqualToString: @""] && ![aGoal2 isEqualToString: goal2]) {
        self.modified = YES;
    }
    goal2 = aGoal2;
}

- (void) setCalendarEventIdentifier:(NSString *)eventIdentifier {
    
    self.modified = YES;
    calendarEventIdentifier = eventIdentifier;
}

- (NSString *)description
{
    NSString *descriptionString = [[NSString alloc] initWithFormat:@"\ndate: %@\nGoal 1: %@\nGoal 2: %@\n\n", date, goal1, goal2];
    return descriptionString;
}
@end
