//
//  Guide.h
//  MoveCoachMobile
//
//  Created by Stephen Barrs on 8/29/12.
//

#import <Foundation/Foundation.h>
#import "GuideSummary.h"

@class ProgressCheckIn;

@interface Guide : NSObject <NSCoding> {
    int index;
}

/**
 * start date is the date the user first clicked on this guide
 **/
@property (nonatomic, strong) NSDate *startDate;

/**
 * end date is the date this module can be ended (e.g. 1 week or 2 weeks from startDate)
 *
 * convieniece property derived from startDate and duration
 **/
@property (nonatomic, strong) NSDate *endDate;

/**
 * Actual Guide end date is the date this module actually ended and was summarized
 *
**/
@property (nonatomic, strong) NSDate *actualGuideEndDate;
    
    
/**
 * This is the amount of time this guide must be active before the next guide can begin
 *
 * for now it is just an int but will probably be in seconds or another NSDate format
 **/
@property (nonatomic) int duration;

/**
 * this is set to YES when the user starts this guide
 **/
@property (nonatomic) BOOL isActive;

/**
 * this is set to YES when the startDate + duration is complete
 **/
@property (nonatomic) BOOL isComplete;

/**
 * This is a reference to the summary for this Guide.
 **/
@property (nonatomic, strong)GuideSummary *currentSummary;

/**
 * This mutable dictionary retains a collection of GuideSummary objects for this Guide.
 */
@property (nonatomic, strong)NSMutableArray *summaries;


/**
 *  This property holds a progressCheckIn object.  It is NIL unless this is guide 7 or 11.
 */
@property (nonatomic, strong) ProgressCheckIn *progressCheckIn;


/**
 * custom init
 */
- (id)initWithIndex:(int)guideIndex;

/**
 * override set start date so we can also set the end date once the start date is known
 **/
- (void) setStartDate;

/**
 * override description to format presentation
 **/
- (NSString *) description;

/**
 * This method creates the Guide Summary for the current Guide.
 **/
- (void)summarizeGuide;

@end
