//
//  GuideSummary.h
//  MoveCoachMobile
//
//  Created by Joel Russell on 9/27/13.
//

#import <Foundation/Foundation.h>
#import "UserData.h"
#import "WeightGoal.h"
#import "ActivityGoal.h"
#import "DietGoal.h"

/**
 *  This Class is part of the GuideTimer model and represents a snapshot of the user's progress at the time each Guide is completed. Each instance of the Guide Class maintains a reference to the corresponding GuideSummary.
 */
@interface GuideSummary : NSObject <NSCoding>

/**
 * This is the integer identifier of the Guide being summarized (i.e., 1-11)
 **/
@property (nonatomic)int guideId;

/**
 * This is the date/time at which the guide was completed & summarized
 **/
@property (nonatomic)NSDate *dateTime;

/**
 * This is the initial weight of the user upon enrollment in MOVE! 
 **/
@property (nonatomic)float startingWeight;

/**
 * This is the weight of the user at the time of Guide completion
 **/
@property (nonatomic)float currentWeight;

/**
 * This is the user's daily caloric intake goal at the time of Guide completion.
 **/
@property (nonatomic)float dailyCalorieGoal;

/**
 * This is the user's Body Mass Index (BMI) at the time of guide completion.
 **/
@property (nonatomic)float bodyMassIndex;

/**
 * This is the current Weight Goal at the time of Guide completion.
 **/
@property (nonatomic, strong)WeightGoal *weightGoal;

/**
 * This is the current Activity Goal at the time of Guide completion.
 **/
@property (nonatomic, strong)ActivityGoal *activityGoal;

/**
 * This is the current Diet Goal at the time of Guide completion.
 **/
@property (nonatomic, strong)DietGoal *dietGoal;

/**
 *  This is the primary method to instantiate a Guide Summary object with the statement id# of the Guide being completed. The remaining properties will be set to their current values at the time of Guide completion.
 *
 *  @param aGuideId - The id for the Guide being summarized (i.e., 1-11).
 */
- (id)initWithGuideId:(int)aGuideId;

/**
 * This method calls the framework to generate a PDF document with the details of the Guide Summary.
 **/
- (void)generatePDF;

@end
