//
//  GuideSummary.m
//  MoveCoachMobile
//
//  Created by Joel Russell on 9/27/13.
//

#import "GuideSummary.h"
#import "Guide.h"
#import "GuideTimer.h"

@implementation GuideSummary
@synthesize guideId, dateTime, startingWeight, currentWeight, dailyCalorieGoal, bodyMassIndex, weightGoal, activityGoal, dietGoal;

- (id)init
{
    return [self initWithGuideId:0];
}

- (id)initWithGuideId:(int)aGuideId
{
    self = [super init];
    UserData *ud = [UserData dataStore];
    
    if (self) {
        
        Guide *currentGuide = [[[GuideTimer defaultStore] guideTracker] objectForKey:[NSNumber numberWithInt:aGuideId]];
        
        if (![currentGuide actualGuideEndDate]) {
            [currentGuide setActualGuideEndDate:[NSDate date]];
        }
        
        self.guideId = aGuideId;
        self.dateTime = [currentGuide actualGuideEndDate];
        self.startingWeight = [ud getStartingWeight];
        self.currentWeight = [ud getCurrentWeight];
        self.dailyCalorieGoal = [ud getCalorieGoal];
        if (((guideId + 1) % 2) != 0) {
            self.bodyMassIndex = [ud getBMI];
        } else {
            self.bodyMassIndex = 0.0;
        }
        self.weightGoal = [ud getCurrentWeightGoal];
        self.activityGoal = [ud getCurrentActivityGoal];
        self.dietGoal = [ud getCurrentDietGoal];
    }
    return self;
}

- (id)initWithCoder:(NSCoder *)aDecoder
{
    self = [super init];
    
    if (self) {
        [self setGuideId:[aDecoder decodeIntForKey:@"guideId"]];
        [self setDateTime:[aDecoder decodeObjectForKey:@"dateTime"]];
        [self setStartingWeight:[aDecoder decodeFloatForKey:@"startingWeight"]];
        [self setCurrentWeight:[aDecoder decodeFloatForKey:@"currentWeight"]];
        [self setDailyCalorieGoal:[aDecoder decodeFloatForKey:@"dailyCalorieGoal"]];
        [self setBodyMassIndex:[aDecoder decodeFloatForKey:@"bodyMassIndex"]];
        [self setWeightGoal:[aDecoder decodeObjectForKey:@"weightGoal"]];
        [self setActivityGoal:[aDecoder decodeObjectForKey:@"activityGoal"]];
        [self setDietGoal:[aDecoder decodeObjectForKey:@"dietGoal"]];
    }
    return self;
}

- (void)encodeWithCoder:(NSCoder *)aCoder
{
    [aCoder encodeInt:guideId forKey:@"guideId"];

    [aCoder encodeObject:dateTime forKey:@"dateTime"];
    
    [aCoder encodeFloat:startingWeight forKey:@"startingWeight"];
    
    [aCoder encodeFloat:currentWeight forKey:@"currentWeight"];
    
    [aCoder encodeFloat:dailyCalorieGoal forKey:@"dailyCalorieGoal"];
    
    [aCoder encodeFloat:bodyMassIndex forKey:@"bodyMassIndex"];
    
    [aCoder encodeObject:weightGoal forKey:@"weightGoal"];
    
    [aCoder encodeObject:activityGoal forKey:@"activityGoal"];
    
    [aCoder encodeObject:dietGoal forKey:@"dietGoal"];
}

- (void)generatePDF
{
    // TODO: implement generatePDF method.
}
@end
