//
//  ResourceData.h
//  MoveCoachMobile
//
//  Created by Stephen Barrs on 1/14/13.
//

#import <Foundation/Foundation.h>

/**
 *  This Class manages a Resource that represents content for the App.  Currently, only PDF files are managed by ResourceContent.  This Class is used by GenericResourcesListViewController, with an instance of this class instantiated for each available PDF resource.
 */
@interface ResourceContent : NSObject

/**
 *  This is the name of the resource and is used when displaying the resource to the user.
 */
@property (nonatomic, strong) NSString *name;

/**
 *  This is a MOVE specific identifier that allows the resource to be ategorized according to MOVE specific rules. This was requested to be kept in use by the Product Owners to assist Veterans in identifiying specific resources when discussing with their health care provider
 */
@property (nonatomic, strong) NSString *identifier;

/**
 *  This is the URL to the resource.  Currently all resources are hosted on a public MOVE Web Server.
 */
@property (nonatomic, strong) NSString *url;

/**
 *  This method will instantiate a new ResourceContent object.
 *
 *  @param resourceName - The user friendly name of the resource.  Saved to the name property.
 *
 *  @param resourceIdentifier - The MOVE specific identifier of this resource.  Saved to the identifier property.
 *
 *  @param resourceUrl - The URL to this resource on the MOVE public facing Web Server.  Saved to the url property.
 */
- (id)initWithName:(NSString *)resourceName andIdentifier:(NSString *)resourceIdentifier andUrl:(NSString *)resourceUrl;

@end
