//
//  UserData.h
//  MoveCoachMobile
//
//  Created by Alex Morgan on 8/30/12.
//

#import <Foundation/Foundation.h>
@class SurveyData;
@class SlipEvent;
@class TriggerData;
@class WeightData;
@class ImageData;
@class WeightGoal;
@class ActivityGoal;
@class DietGoal;

/**
 *  This Class is part of the Data Model and represents a User and all the data associated with them.  In order to write this data to device disk this Class conforms to the NSCoding protocol.
 */
@interface UserData : NSObject <NSCoding>

@property (nonatomic)BOOL eulaComplete;
@property (nonatomic)BOOL initialWarningComplete;

@property (nonatomic)BOOL bmiFirst;

@property (nonatomic,strong)NSString *lastBMIStr;

@property (nonatomic) float height; /**< The user's height */

//@property (nonatomic, strong)NSDate *dateOfBirth; /**<  */

@property (nonatomic)NSInteger age; /**< The user's Age */

@property (nonatomic,strong)NSString *gender; /**< The user's Gender */

@property (nonatomic)float activityFactor; /**< TODO: NEED INPUT HERE */

@property (nonatomic,strong)NSMutableArray *weights; /**< This NSMutableArray holds WeightData objects for each weight entry a user has input */
@property (nonatomic, strong) NSMutableDictionary *weightsHashByDate; /**< This Hash holds WeightData objects for each weight entry a user has input key=DateNormalizedWithoutTime value=array of WeightData objects.  This data sturcture may replace the NSMutableArray at some point in time.  For now they will both exist. */

@property (nonatomic,strong)NSMutableArray *stepsTaken; /**< This NSMutableArray holds StepData objects for each pedometer step entry a user has input */

@property (nonatomic,strong)NSMutableArray *customWorkout; /**< This NSMutableArray holds objects for each custom workout entry a user has input */

@property (nonatomic) BOOL weightCalorieCategoryHasChanged; /**< This BOOL is set to YES when a user enters a weight that causes them to enter a new weight category */

@property (nonatomic, strong) NSMutableDictionary *imageStore;  /**< This dictionary holds all the self portrait images the user has added for comparisson. key=date Image Added, value=ImageData object */

@property (nonatomic,strong)NSMutableArray *foodEntries; /**< This NSMutableArray holds DietData objects for each dietary entry a user has input */

@property (nonatomic, strong) NSMutableDictionary *caloriesByDateDictionary; /**< This NSMutableDictionary holds calorie sums for each date */

@property (nonatomic,strong)NSMutableArray *mealHungerEntries;  /**< This NSMutableArray holds the hunger level entries for each meal */

@property (nonatomic,strong)NSMutableArray *mealMoodEntries;   /**< This NSMutableArray holds the mood entries for each meal */

@property (nonatomic,strong)NSMutableArray *mealMPCHEntries;   /**< This NSMutableArray holds the Mindful, Portion Controlled and Healthy BOOL entries for each meal */

@property (nonatomic,strong)NSMutableArray *customNutrition; /**< This NSMutableArray holds nutrition objects for each custom dietary entry a user has input */

@property (nonatomic,strong)NSMutableArray *customPortion; /**< This NSMutableArray holds portion objects for each custom dietary entry a user has input */

@property (nonatomic,strong)NSMutableArray *favoriteNutrition; /**< This NSMutableArray holds nutrition objects for each favorite dietary item a user has input */

@property (nonatomic,strong)NSMutableArray *favoritePortion; /**< This NSMutableArray holds portion objects for each favorite dietary item a user has input */

@property (nonatomic,strong)NSMutableArray *paEntries; /**< This NSMutableArray holds PAData objects for each dietary entry a user has input */

@property (nonatomic,strong)NSMutableArray *favoritePA; /**< This NSMutableArray holds physical activity objects for each favorite item a user has input */

@property (nonatomic,strong)NSMutableArray *recallActivity; /**< This NSArray contains PARecallData objects that represent the activities entered in Guide 8 Chapter 3 (G8C3RecallEntryViewController) */

@property (nonatomic, strong)NSMutableArray *weightGoals; /**< This mutable array allows MCM to maintain a history of the user's weight goals as they progress through the MOVE! program */

@property (nonatomic)WeightGoal *draftWeightGoal; //**< This reference to a "draft" weight goal is kept during an edit session, if the current weight goal is archivable. If changes have occurred at the end of the session, the corresponding goal will be added to the weightGoals array and subsequently saved. */

@property (nonatomic)ActivityGoal *draftActivityGoal; //**< This reference to a "draft" activity goal is kept during an edit session, if the current activity goal is archivable. If changes have occurred at the end of the session, the corresponding goal will be added to the activityGoals array and subsequently saved. */

@property (nonatomic)DietGoal *draftDietGoal; //**< This reference to a "draft" diet goal is kept during an edit session, if the current diet goal is archivable. If changes have occurred at the end of the session, the corresponding goal will be added to the dietGoals array and subsequently saved. */

// SMART Goals User Input

@property (nonatomic,strong)NSString *dietSMARTGoal1; /**< This represents the user's input for their first Dietary SMART Goal */

@property (nonatomic,strong)NSString *dietSMARTGoal2; /**< This represents the user's input for their second Dietary SMART Goal */

@property (nonatomic,strong)NSMutableArray *dietGoals; /**< This mutable array allows MCM to maintain a history of the user's diet goals as they progress through the MOVE! program */

@property (nonatomic,strong)NSString *activitySMARTGoal1; /**< This represents the user's input for their first Physical Activity SMART Goal */

@property (nonatomic,strong)NSString *activitySMARTGoal2; /**< This represents the user's input for their second Physical Activity SMART Goal */

@property (nonatomic,strong)NSMutableArray *activityGoals; /**< This mutable array allows MCM to maintain a history of the user's activity goals as they progress through the MOVE! program */

// Motivation screen User Input
@property (nonatomic,strong)NSString *joinedMOVE1; /**< This represents the user's first response to the question: "Why have you joined MOVE?" */

@property (nonatomic,strong)NSString *joinedMOVE2; /**< This represents the user's second response to the question: "Why have you joined MOVE?"  */

@property (nonatomic,strong)NSString *changeWillHelp1; /**<  This represents the user's first response to the statement: "As a result of participating in MOVE I hope to:" */

@property (nonatomic,strong)NSString *changeWillHelp2; /**<  This represents the user's second response to the statement: "As a result of participating in MOVE I hope to:"  */

@property (nonatomic)float caloriesConsumed; /**< TODO - IS THIS USED? */

@property (nonatomic)float caloriesBurned; /**< TODO - IS THIS USED? */

//MyGoalsAndProgress
@property (nonatomic, strong)NSString *goalsViewToPush; /** This is the name of the view to push when the user presses either the Update Diaries button on the My Goals view, or the Update Goals button on the Self-Monitor view it serves as a navigational sentinel to avoid cyclic seques between the two views **/

// Fatty Foods User Input
@property (nonatomic, strong)NSMutableArray *fattyFoods; /**< This NSArray holds NSStrings entered by the user to describe Fatty Foods they currently eat.  This data is collected in Guide 6, Ch1 (G6C1FattyFoodEntryViewController) */

@property (nonatomic, strong)NSMutableArray *fattyFoodReductionMethods; /**< This NSArray holds NSStrings selected by the user to describe the method they will use to consume less Fatty Foods.  Options are: Frequency, Amount and Substitution.  This array index corresponds to the array index of fattyFoods (e.g. the fatty food stored in fattyFoods[1] will be rectified by the method described by the string in fattyFoodReductionMethods[1]  This data is collected in Guide 6, Ch1 (G6C1FattyFoodEntryViewController)  */

@property (nonatomic, strong)NSMutableArray *fattyFoodEnteredTexts; /**< This NSArray holds NSStrings entered by the user to describe the specific frequency, amount or substitution they will use to consume less Fatty Foods.  This array index corresponds to the array index of fattyFoods (e.g. the fatty food stored in fattyFoods[1] will be rectified by the specific text in fattyFoodEnteredTexts[1]  This data is collected in Guide 6, Ch1 (G6C1FattyFoodEntryViewController) */

//@{
/**
 *  This property holds NSStrings entered by the user to describe ways the user can plan to reach their weight loss goal.  This data is collected in Guide 8, Chapter 1 (G8C15WaysViewController)
 */
@property (nonatomic, strong)NSMutableArray *planningArray;
//@}
//@{
/**
 *  This property holds NSStrings entered by the user to describe rewards associated with the planning steps in planningArray.  This data is collected in Guide 8, Chapter 1
 */
@property (nonatomic, strong)NSMutableArray *planningRewardArray;
//@}

@property (nonatomic)float sleep; /**< This property represents the amount of sleep a user gets per week. It is entered in Guide 5, Chapter 1 as part of the Activity Pyramid Entries (G5CurrentPyramidViewController) */

@property (nonatomic)float sedentary; /**< This property represents the amount of time a user is sedentary per week. It is entered in Guide 5, Chapter 1 as part of the Activity Pyramid Entries (G5CurrentPyramidViewController) */

@property (nonatomic)float leisure; /**< This property represents the amount of time a user spends on liesure activities per week. It is entered in Guide 5, Chapter 1 as part of the Activity Pyramid Entries (G5CurrentPyramidViewController) */

@property (nonatomic)float strength; /**< This property represents the amount of time a user spends on strength training activities per week. It is entered in Guide 5, Chapter 1 as part of the Activity Pyramid Entries (G5CurrentPyramidViewController) */

@property (nonatomic)float flexibility; /**< This property represents the amount of time a user spends on flexibility training activities per week. It is entered in Guide 5, Chapter 1 as part of the Activity Pyramid Entries (G5CurrentPyramidViewController) */

@property (nonatomic)float anrTime; /**< This property represents the amount of hours a user spends on aerobic and recreational activities per day. It is entered in Guide 5, Chapter 1 as part of the Activity Pyramid Entries (G5CurrentPyramidViewController) */

@property (nonatomic)float anrDays; /**< This property represents the number of days per week that a user participates in aerobic and recreational activities. It is entered in Guide 5, Chapter 1 as part of the Activity Pyramid Entries (G5CurrentPyramidViewController) */

@property (nonatomic)float everyday; /**< This property represents the amount of time a user spends on everyday activities per week. It is entered in Guide 5, Chapter 1 as part of the Activity Pyramid Entries (G5CurrentPyramidViewController) */

// Guide 9 Chapter 2 Trigger and foods data;
@property (nonatomic,strong)NSMutableArray *envTriggers; /**< TODO: need more info- This data is collected in Guide 9, chapter 2 (G9C2TriggerViewController) */

@property (nonatomic,strong)NSMutableArray *envBadFoods; /**< TODO need more info */

@property (nonatomic,strong)NSMutableArray *fixTriggers; /**< TODO: need more info- This data is collected in Guide 9, chapter 2 (G9C2FixViewController) */

@property (nonatomic,strong)NSMutableArray *fixes; /**< TODO need more info */

@property (nonatomic, strong)NSMutableArray *triggerFixData; /**< TODO need more info */


//Guide 10 Ch 2 Chain of Events data
@property (nonatomic, strong)NSArray *slipEvents; /**< This property is an NSArray containing SlipEvent objects.  Each SlipEvent object contains information about a specific slip event that the user has described.  This data is collected in Guide 10, Chapter 2 (G10Ch2Screen1ViewController). */

@property (nonatomic, strong)NSString *slipEventDescription; /**< This is the Description of the SlipEvent.  This data is collected in Guide 10, Chapter 2 (G10Ch2Screen1ViewController). */

// Survey Data
@property (nonatomic, strong)SurveyData *surveyData; /**< The SurveyData object holds all user input regarding the MOVE 23 Questionaire survey.  This data is collected throughout Guides 1-4 in the following Classes: G1InitialSurveyViewController, G1GetReadyViewController, G2GetReadyViewController, G3GetReadyViewController, G4GetReadyViewController */

@property (nonatomic, strong)NSString * userArchiveFilePath; /**< This string holds the path to the archive file on local disk.  It is set when the archive is retrieved and used when writing to disk. */

@property (nonatomic) BOOL isVeteran;

@property (nonatomic,strong)NSString *entryDateString;

@property (nonatomic,strong)NSString *previousPAEntryScreen;

@property (nonatomic,strong)NSString *paEntryScreen; /**< This string holds the name of the selected physical activity screen */

@property (nonatomic,strong)NSString *currentMeal;

@property (nonatomic,strong)NSString *previousDietEntryScreen;

@property (nonatomic,strong)NSString *dietEntryScreen; /**< This string holds the name of the selected physical activity screen */

@property (nonatomic) BOOL hasSeenVideoHelp;

@property (nonatomic) BOOL askedForNotifications;

@property (nonatomic)float calorieGoalOffset;

@property (nonatomic)BOOL belowMinCalGoal;

+ (UserData *) dataStore; /**< The UserData Class follows the singleton design pattern and this method is used to access the single instance.   @return UserData object */

-(float)getBMI; /**< Calulates and returns users Body Mass Index  @return the users Body Mass Index */

//-(float)getAverageCalorieBalance; /**<  NOT USED YET @return */
-(float)getAverageCalorieBalanceForGuide:(int)guideId;

-(float)getDailyCalorieBalance; /**< NOT USED YET  @return */

- (int) getWeightCalorieCategoryForWeight:(float)weight; /**< This method computes a weight category based on the weight passed in.  @param weight  @return weight category as in int */

- (NSString *) getCaloriesPerDayForWeightCalorieCategory:(int)category formattedForAccessibility:(BOOL)flag; /**< This method returns a human readable text string describing the weight category based.  @param category - this is the category for a specific weight, for example as returned by the getWeightCalorieCategoryForWeight:(float)weight method  @return A human readable string representing the weight category */

- (float)getWeightLostLBS; /**< Computes the total number of pounds a person has lost since weight logging began  @return a float representing the number of pounds lost */

- (float)getWeightLostPercent; /**< Computes the total percentage of their starting weight a person has lost since weight logging began  @return a float representing the percantage of the starting weight the user has lost  */

- (float)getCalorieGoal; /**< Computes the daily goal for caloric consumption */

- (void)addWeightGoal: (float)referenceWeight; /**< This method allows ad hoc creation of a WeightGoal instance with a baseline weight, while adding it to the weightGoals array */

- (void)addWeightGoalToWeightGoals:(WeightGoal *)weightGoal; /**< This method allows addition of an existing WeightGoal instance to the weightGoals array */

- (void)removeWeightGoal: (WeightGoal *)weightGoal; /**< This method allows removal of an existing WeightGoal instance from the weightGoals array */

- (WeightGoal *)getCurrentWeightGoal; /**< This method returns the current (i.e., most recent) WeightGoal for the user. */

- (WeightGoal *)getStartingWeightGoal; /**< This method returns the starting (i.e., earliest) WeightGoal for the user. */

- (WeightGoal *)getWeightGoalForDate: (NSDate *)date; /**< This method gets the weight goal for a given date (i.e., the most current weight goal as of the date in question) */

- (void)createDraftWeightGoal: (WeightGoal *)currentWeightGoal; /**< This method creates a draft weight goal from the current weight goal, when it is identified as archivable. The draft will be added to the weightGoals array when saveState is called, if any of its properties have been changed during the edit session. */

-(void)addActivityGoal: (NSString *)goal1Text; /**< This method allows ad hoc creation of an ActivityGoal instance with a goal text, while adding it to the activityGoals array */

- (void)addActivityGoalToActivityGoals:(ActivityGoal *)activityGoal; /**< This method allows addition of an existing ActivityGoal instance to the activityGoals array */

-(void)removeActivityGoal: (ActivityGoal *)activityGoal; /**< This method allows removal of an existing activityGoal instance from the activityGoals array */

-(ActivityGoal *)getCurrentActivityGoal; /**< This method returns the current (i.e., most recent) ActivityGoal for the user. */

-(ActivityGoal *)getStartingActivityGoal; /**< This method returns the starting (i.e., earliest) ActivityGoal for the user. */

- (void)createDraftActivityGoal: (ActivityGoal *)currentActivityGoal; /**< This method creates a draft activity goal from the current activity goal, when it is identified as archivable. The draft will be added to the activityGoals array when saveState is called, if any of its properties have been changed during the edit session. */

-(void)addDietGoal: (NSString *)goal1Text; /**< This method allows ad hoc creation of a DietGoal instance with a goal text, while adding it to the dietGoals array */

- (void)addDietGoalToDietGoals:(DietGoal *)dietGoal; /**< This method allows addition of an existing DietGoal instance to the dietGoals array */

-(void)removeDietGoal: (DietGoal *)dietGoal; /**< This method allows removal of an existing DietGoal instance from the dietGoals array */

-(DietGoal *)getCurrentDietGoal; /**< This method returns the current (i.e., most recent) DietGoal for the user. */

-(DietGoal *)getStartingDietGoal; /**< This method returns the starting (i.e., earliest) DietGoal for the user. */

- (void)createDraftDietGoal: (DietGoal *)currentDietGoal; /**< This method creates a draft diet goal from the current diet goal, when it is identified as archivable. The draft will be added to the dietGoals array when saveState is called, if any of its properties have been changed during the edit session. */

-(float)getDailyCalorieGoal; /**< TODO: is this being used and populated correctly  @return */

-(float)getCurrentWeight; /**<  This method pulls the latest WeightData object from the weights array and returns it @return the last weight entry made by the user*/

-(float)getStartingWeight; /**< This method pulls the first WeightData object from the weights array and returns it @return the first weight entry made by the user  @return */

//these methods really need to be pulled out into something like weightManager class
- (NSArray *)getWeightsForDate:(NSDate *)keyDate;/**< This method gets the WeightData objects from the weightsHashByDate  and returns them as @return an array of weight Objects for @param date */
- (WeightData *) getLatestWeightDataForDate:(NSDate *)keyDate; /**< This method calculates the WeightData object with the most recently entered date for this date.  @return a weight data object that is the latest entered for @param the date requested */
- (WeightData *) getLatestWeightData;/**< This method calculates the WeightData object with the most recently entered date */

-(NSDate *)getStartingWeightDate; /**< This method pulls the dateCreated for the first WeightData object from the weights array and returns it @return the first weight entry made by the user  @return */

-(void)populateTempData; /**<  This is a test harness to populate temp data into the app  */

//- (void)addWeight:(float)weight; /**< This method allows the system to add a weight to the weights array @param weight - The weight to add   */

- (void)addWeight:(float)weight andDate:(NSDate *)date; /**< This method allows the system to add a weight to the weights array @param weight - The weight to add   */

- (void)addWeightWithWeightData:(WeightData *)wd; /**< This method allows us to create a WeightData object manually and then add it to the weights array   */

- (void)removeWeight: (WeightData *)wd; /**< This method allows removal of an existing Weight instance from the weights array */

- (void)addDietEntryWithFoodName:(NSString *)foodname date:(NSString *)date calories:(float)calories foodCode:(NSString *)foodcode portionFactor:(float)portionfactor portionDesc:(NSString *)portiondesc servings:(float)servings meal:(NSString *)meal; /**< This method allows us to create a DietData object and then add it to the foodEntries array */

- (NSString *) getCalorieRange; /**< This convinient method returns the current Calorie Range based on the user's current weight  @return A human readable string representing the current calorie range*/

- (float) getCaloriesBurnedOnDate:(NSDate *)date; /**< This convenience method returns the total number of Calories burned on a given date */
- (float) getCaloriesConsumedOnDate:(NSDate *)date; /**< This convenience method returns the total number of Calories consumed on a given date */


- (int) getStepsForDate:(NSDate *)date; /**< This convenience method returns the total number of steps taken on a given date */

- (NSDate *) getOldestDietEntry;
- (NSDate *) getOldestActivityEntry;
- (NSDate *) getOldestWeightDate;

#pragma -mark
#pragma -image methods

- (void) addImageToImageStore:(UIImage *)image withDate:(NSDate *)date; /**< This method will add an ImageData object to the ImageStore NSDictionary.  @param image - THe image to be added.   @param date - The date the image was added.  */

- (void) removeImageFromImageStoreForKey:(NSDate *)key; /**< This method deletes a specific ImageData object from the ImageStore hash as specified by the key  @param key - the string representation of the date the image was added. */

- (ImageData *) getImageDataForKey:(NSDate *)key; /**< This method returns a specific ImageData object as specified by the key  @param key - the string representation of the date the image was added.   @return ImageData object associated with key.  */

- (NSArray *)getSelectedImages; /**< This method will return an array containing the imageData objects that are selected for comparison.  There should only ever be two objects maximum selected at a time.  @return an array containing ImageData objects that have compare = YES*/

//this will either set or remove this image as selected for compare
- (void) setImageSelectionBool:(ImageData *)imageData withFlag:(BOOL)flag;

#pragma -mark
- (BOOL) saveState; /**< This method kicks off the process to write all data in the data model to device disk  @return YES if successful and NO if not successful */

/**
 *
 *
 *  @param
 *
 *  @param
 *
 */
- (void)addPARecallActivity:(NSString *)act andDuration:(NSString *)dur;

/**
 *
 *
 *  @param
 *
 *  @param
 *
 */
- (void)addTrigger:(NSString *)t andFix:(NSString *)f;

+ (BOOL) remove; /**<   @return */


- (void) convertAllDataToJson;


/*
 measurments:
 height - float
 weight - dictionary
 
 goals (may be separate class):
 weightLossRate - float
 totalWeightLossDesired - float
 dietSMARTGoals - array
 activitySmartGoals - array
 
 functions (computedFields):
 -(float)getBMI
 -(int)getAverageCalorieBalance
 -(float)getWeightLostLBS  (maybe use max weight) <--
 -(float)getWeightLost%
 -(float)getPercentWeightLossDesiredBasedonLBS
 -(float)getLBSWeightLossDesiredBasedonPercent
 -(int)getDailyCalorieGoal
 
 -(float)targetBMIGoaltoCalulateLBSandPercentWeightLoss
 */

@end
