define(function(require) {
    var log = require("loglevel");

    var UserData = Backbone.Model.extend({
        localStorage: new Backbone.LocalStorage("UserData"),

        deferred: "",

		defaults: {
			testingConfig: "selected"
		},
		
        initialize: function() {
            // Fetch user data from local storage
            this.deferred = this.fetch();
        },

        parse: function(response) {
            log.debug(JSON.stringify(response));
            return response[0];
        },

        isTesting: function()
        {
        	var testConfig = this.get("testingConfig") === "selected" ? true : false;
        	console.log("isTesting: " + testConfig);
        	return testConfig;
        },

        // Overriding Backbone 'clear' method since we don't want to delete the id
        // attribute.
        clear: function() {
            this.set({
                isEulaComplete: false,
                testingConfig: "selected",
                isInitialWarningComplete: false,
                hasSeenVideoHelp: false,
                initialHeight: undefined,
                heightFTComponent: undefined,
                heightINComponent: undefined,
                initialWeight: undefined,
                firstWeight: undefined,
                currentWeight: undefined,
                weight: [],
                initialWeightLossRange: undefined,
                dailyCalorieGoal: undefined,
                medicalCalorieAdjustmentText: "Tap to set Medical Calorie Adjustment",
                mcaValue: undefined,
                goalReachedDate: undefined,
                previousGoalReachedDate: undefined,
                initialPercentToLose: undefined,
                initialLBSToLose: undefined,
                initialTargetWeight: undefined,
                initialAge: undefined,
                initialGender: undefined,
                joinedMOVE1: undefined,
                joinedMOVE2: undefined,
                changeWillHelp1: undefined,
                changeWillHelp2: undefined,
                paSmartGoal1: undefined,
                paSmartGoal2: undefined,
                activityGoalsCheckinDate: undefined,
                dietSmartGoal1: undefined,
                dietSmartGoal2: undefined,
                dietGoalsCheckinDate: undefined,
                isAboutSMGDone: false,
                initialDate: undefined,
                firstTimeEntriesComplete: undefined,
                bodyMassIndex: undefined,
                weightLost: undefined,
                percentWeightLost:undefined,
                guideChapterComplete: [],
                guideHandoutComplete: [],
                selectedDate: undefined,
                guideSnap: [],
                currentGuide: undefined,
                guide2C3SliderValues:[],
                G6C1CurrentFood: undefined,
                G6C1CurrentReductionType: undefined,
                G6C1FattyFoodEntrys:[],
                G8C1CurrentPlan: undefined,
                G8C1CurrentReward:undefined,
                G8C1PlanEntrys:[],
                G8C3ActivityEntrys:[],
                G8C3CurrentTime: undefined,
                G8C3CurrentActivity: undefined,
                triggers:undefined

            });
        },

        reset: function() {
            log.debug("UserData reset() called - setting test data.");
            console.log("UserData reset() called.");

            this.set({
                isEulaComplete: true,
                testingConfig: "selected",
                isInitialWarningComplete: true,
                hasSeenVideoHelp: true,
                initialHeight: 69.0,
                heightFTComponent: 5,
                heightINComponent: 9,
                initialWeight: 300.0,
                firstWeight: 300.0,
                currentWeight: 298.0,
                weight:[{wt:300.0},{wt:298.0}],
                initialWeightLossRange: 0.5,
                dailyCalorieGoal: 2375,
                medicalCalorieAdjustmentText: "Tap to set Medical Calorie Adjustment",
                mcaValue: 0,
                goalReachedDate: "10/04/2016",
                initialPercentToLose: 5.0,
                initialLBSToLose: 15.0,
                initialTargetWeight: 285.0,
                initialAge: 42,
                initialGender: "female",
                joinedMOVE1: "To reduce my weight and be more healthy.",
                joinedMOVE2: "Because my doctor told me I needed to lose weight.",
                changeWillHelp1: "I will have more energy to keep up with the grandkids.",
                changeWillHelp2: "I will fit in to the clothes I wore last year.",
                paSmartGoal1: "Ride my road bike more",
                paSmartGoal2: "Ride my mountain bike more",
                activityGoalsCheckinDate: undefined,
                dietSmartGoal1: "eat fewer donuts",
                dietSmartGoal2: "cook more skratch labs food",
                dietGoalsCheckinDate: undefined,
                isAboutSMGDone: true,
                initialDate: new Date(),
                firstTimeEntriesComplete: true,
                bodyMassIndex: 44.0,
                weightLost: 2.0,
                percentWeightLost:0.7,
                guideChapterComplete: [true],
                guideHandoutComplete: [true],
                selectedDate: "01/22/15",
                guideSnap: [],
                currentGuide: undefined,
                guide2C3SliderValues:[],
                G6C1CurrentFood: "Bacon",
                G6C1CurrentReductionType: "Frequency",
                G6C1FattyFoodEntrys:[],
                G8C1CurrentPlan: undefined,
                G8C1CurrentReward:undefined,
                G8C1PlanEntrys:[],
                G8C3ActivityEntrys:[],
                G8C3CurrentTime: undefined,
                G8C3CurrentActivity: undefined,
                triggers:undefined

            });

            // Save changes to local storage.
            this.save();
        },

        populateDataForDates: function(startDate, endDate, behavior) {

            var currentWeight = this.get("initialWeight");

            // Parse date returns the results in milliseconds. So divide by the number of seconds in
            // 1 day: 1000 * 60 * 60 * 24 = 86,400,000
            var numberOfDays = Math.floor((Date.parse(endDate) - Date.parse(startDate)) / 86400000);

            var pastDate = new Date(this.get("initialDate"));

            // float weightLossRate = [[[UserData dataStore] getCurrentWeightGoal] weightLossRate];
            var weightLossRate = this.get("initialPercentToLose");

            var specialWeightFactor = 10000;
            var weightChangeFactor = weightLossRate;


            //this will also influence how much calories we are after.
            if (behavior === "plateau") {
                specialWeightFactor = 0;
            } else if (behavior === "spike") {
                specialWeightFactor = -weightChangeFactor - .5;
            }

            // BOOL specialFactorInEffect = NO;
            var specialFactorInEffect = false;
            // float lastWeightEntered = initalWeight;
            var lastWeightEntered = this.get("initialWeight");

            // int randomDaysToSkipExercise = arc4random_uniform(numberOfDays) + 1;
            var randomDaysToSkipExercise = Math.floor((Math.random() * numberOfDays) + 1);

            var obj = {};
            for (var i = 0; i < numberOfDays; i++) {

                //this will cause the special behavior to only last 5 days (spike or plateau)
                if (specialWeightFactor < 1000) {
                    if (i > 1 && i < 7) {
                        weightChangeFactor = specialWeightFactor;
                        specialFactorInEffect = true;
                    } else {
                        weightChangeFactor = weightLossRate;
                        specialFactorInEffect = false;
                    }
                }

                if (i == 3) {
                    if (specialFactorInEffect) {
                        currentWeight += .25;
                    } else {
                        currentWeight -= .5;
                    }
                } else if (i % 4 == 0) {
                    currentWeight += weightChangeFactor / 2;
                } else if (i % 5 == 0) {
                    currentWeight -= weightChangeFactor / 2;
                } else if (i % 6 == 0) {
                    currentWeight += (weightChangeFactor / 2);
                } else {
                    currentWeight -= (weightChangeFactor / 2);
                }

                // [
                //     [UserData dataStore] addWeight: currentWeight andDate: pastDate
                // ];
                obj[pastDate] = currentWeight;

                var weightDifference = lastWeightEntered - currentWeight;

                // [self populateDietDataWithCalorieLimitForDate:pastDate withWeightDifference:weightDifference];

                // if (i % randomDaysToSkipExercise != 0) {
                //     [self populateActivityDataWithCalorieLimitForDate:pastDate withEvent:behavior withWeightDifference:weightDifference];
                // }

                // pastDate = [NSDate dateWithTimeInterval: 86400 sinceDate: pastDate];
                pastDate.setDate(pastDate.getDate() + i);
                lastWeightEntered = currentWeight;
            }

        },
        calculateCalorieGoal: function(lossRate, currentWeight){
        	// var percentValue = this.$('#percentInput').val();;
			// var rateValue = this.get("initialWeightLossRange");
			
			// calorie calculations
			// var baselineWeight = this.get("initialWeight");
			
			var minGoal = 1200;
   			var maxGoal = 3500;
   			var goalCal = 1200;
    
 		currentWeight = Number(currentWeight);
 		lossRate = Number(lossRate);
//     
    // var lossRate = UserData.get("initialWeightLossRange");
//     
    if (currentWeight < 200) {
        minGoal = 1200;
        maxGoal = 1500;
        goalCal = minGoal + ((maxGoal - minGoal)*((lossRate-2)/(-2)));
    } else if (currentWeight < 226) {
        minGoal = 1500;
        maxGoal = 1800;
        goalCal = minGoal + ((maxGoal - minGoal)*((lossRate-2)/(-2)));
    } else if (currentWeight < 251) {
        minGoal = 1800;
        maxGoal = 2000;
        goalCal = minGoal + ((maxGoal - minGoal)*((lossRate-2)/(-2)));
    } else if (currentWeight < 301) {
        minGoal = 2000;
        maxGoal = 2500;
        goalCal = minGoal + ((maxGoal - minGoal)*((lossRate-2)/(-2)));
    } else if (currentWeight < 351) {
        minGoal = 2500;
        maxGoal = 3000;
        goalCal = minGoal + ((maxGoal - minGoal)*((lossRate-2)/(-2)));
    } else {
        minGoal = 3000;
        maxGoal = 3500;
        goalCal = minGoal + ((maxGoal - minGoal)*(lossRate/2));
    }
    
/*    if(this.get("mcaValue")){
    goalCal = Number(goalCal) + Number(this.get("mcaValue"));
    }
    
    this.set("dailyCalorieGoal", goalCal);
        */
       return goalCal;
      }
    });

    return new UserData();
});
