define(function(require) {
    var log = require("loglevel"),
        Handlebars = require("handlebars"),
        EventData = require("models/ChainOfEventsModel"),
        template = require("text!templates/G10C2ChainOfEvents-2.html");

    // Compile the template once.
    var compiled_template = Handlebars.compile(template);
    var editingIndex = -1;

    var G10C2ChainOfEvents2View = Backbone.View.extend({
        // Set the id attribute on the div.
        id: "G10C2ChainOfEvents2View",

		model: EventData,

		initialize: function() {
		},

        events: {

            'change #eventoption': function(ev){this.fieldChange(ev, "eventChain");},

            'swipeleft ul#eventOptionsListView li#deletableCells': function(ev){this.getIndexAndRemoveOption(ev, "eventChain");},
            'swiperight ul#eventOptionsListView li#deletableCells': function(ev){this.getIndexAndRemoveOption(ev, "eventChain");},
            'click ul#eventOptionsListView li#deletableCells': function(ev){this.getIndexAndEdit(ev, "eventChain");},
        },

        render: function() {

            $(this.el).html(compiled_template(EventData.toJSON()));

            return this;
        },

       	fieldChange: function (ev, arrayName) {

       		setTimeout(function() {

				var value = ev.target.value;

				if ( value == "" ) return;

				var eventIndex = ev.target.getAttribute("data-event-idx");
				var eventListView = ev.target.parentElement.parentElement.parentElement;

				if (editingIndex > 0)
				{
					EventData.replaceOptionInEvent(arrayName, eventIndex, editingIndex -1, value);

					$('.highlight').text(value);
					$('.highlight').removeClass('highlight');
					editingIndex = -1;
				}
				else
				{
					EventData.addOptionToEvent(arrayName, eventIndex, value);

					$('<li id="deletableCells" data-event-idx="' + eventIndex + '" >').append(value).appendTo(eventListView);
				}
				$(ev.target).val('');
				$(eventListView).listview("refresh");

			}, 100);
       	},

		getIndexAndRemoveOption: function (ev, arrayName) {
			var selectedIndex = $(ev.currentTarget).index();
			var titleString = "Are you sure you want to delete " + $(ev.currentTarget).text();

			function onConfirm(buttonIndex) {
  				if (buttonIndex === 1) {
					//this accounts for the odd way that JQuery returns indexes starting at 1 instead of 0
					selectedIndex = selectedIndex-1;

					var success = false;
					var eventIdx = ev.currentTarget.getAttribute("data-event-idx");
					success = EventData.removeOptionFromEventList(arrayName, eventIdx, selectedIndex);

					if (success) {
						$(ev.currentTarget).remove();
					}
				}
			}

			if ( typeof navigator.notification == 'undefined') {
				if (confirm(titleString)) onConfirm(1);
			} else {
				navigator.notification.confirm(
					' ', // message
					onConfirm,            // callback to invoke with index of button pressed
					titleString,           // title
					['Yes','No']     // buttonLabels
				);
			}
		},

		// toggle editing of current list item
		getIndexAndEdit: function (ev, arrayName) {
			console.log("getIndexAndEdit");

			// makes user force toggle to stop editing - didn't like it
// 			var selectedIndex = $(ev.currentTarget).index();
// 			if (editingIndex > 0 && selectedIndex != editingIndex) return;

			var selectedEventIdx = ev.target.getAttribute("data-event-idx");
			var editSelector = "input[name=Event" + selectedEventIdx + "]";

			if ( $(ev.currentTarget).hasClass('highlight') ) {
				// disable editing
				editingIndex = -1;
				$(ev.currentTarget).removeClass('highlight');
				$(editSelector).val('');
			}
			else {
				// enable editing
				var selectedIndex = $(ev.currentTarget).index();
				var editText = $(ev.currentTarget).text();

				editingIndex = selectedIndex;

				$('.highlight').removeClass('highlight');
				$(ev.currentTarget).addClass('highlight');
				$(editSelector).val(editText);
				$(editSelector).focus();
			}
		}

    });

    return G10C2ChainOfEvents2View;
});
