define(function(require) {
    var log = require("loglevel"),
	    Handlebars = require("handlebars"),
        UserData = require("models/UserData"),
        slideHelper = require ("slideHelper"),	// required for jssor stuff
        slide = require ("slider"),	// required for jssor stuff
        template = require("text!templates/G8C2FoodSubs.html");

    var compiled_template = Handlebars.compile(template);

    var wrongAnswers = [];
    var portionsArray, foodsArray;

    var PortionsView = Backbone.View.extend({
        id: "g8C2FoodSubsView",

        events: {
        	"click #check-answer": "checkAnswer",
            "click #resourceListItem": "listItemTapped"
        },

		initialize: function() {
			this.listenToOnce(this.model, 'change:leftSlider', this.updateScale);

			portionsArray = this.model.get ('healthyFoodList');
			foodsArray = this.model.get ('fastFoodList');
			$.each(foodsArray, function(index, value) // is there a better way to do this?
			{
				wrongAnswers[index] = 0;
			});
			console.log("portionsArray: " + portionsArray);

			var that = this;

			Handlebars.registerHelper('getSliderPortions', function() {
				var listData = "";
				// var imagePath = "../www/images/icons/guides/guide2/"; // device path
// 				var imagePath = "../images/icons/guides/guide2/"; // browser path
				$.each (portionsArray, function(index, value)
				{
      				listData += "<div>";
      				// listData += "<img u='image' src='" + imagePath + value[0] + "@2x.png' />";
      				listData += "<h1 style='float: right; font-size: 500%; margin-top: 300px; margin-right: 50px'>" + value[0] + "</h1>";
      				listData += "</div>";
			  	});
			  	console.log("portion pics: " + listData);
			  	return new Handlebars.SafeString(listData);
			});


			Handlebars.registerHelper('getSliderFoods', function() {
				var listData = "";
				$.each (foodsArray, function(index, value)
				{
      				listData += "<div>";
      				// doesn't blow up
      				// listData += "<div>" + value[0] + "</div>";
      				// what i want to use but can't cause it blows up on device
      				// listData += "<h1 style='float: right; line-height: 600px; font-size: 500%; vertical-align: middle;'>" + value[0] + "</h1>";

      				listData += "<h1 style='float: left; font-size: 500%; margin-top: 300px; margin-right: 50px'>" + value[0] + "</h1>";
      				listData += "</div>";
			  	});
			  	console.log("food list: " + listData);
			  	return new Handlebars.SafeString(listData);
			});

			Handlebars.registerHelper('getPhoneOnlyDisplay', function() {
				return (isTablet) ? "none" : "block";
			});

		},

        render: function() {
            this.$el.html(compiled_template(this.model));

		    var renderDeferred = $.Deferred();

		 	var navDisplay = (isTablet) ? 2 : 1;
			// captions and/or transitions blow up on device
	     	var sliderOptions = {
            		$AutoPlay: false,                                    //[Optional] Whether to auto play, to enable slideshow, this option must be set to true, default value is false
            		$PlayOrientation: 2,                                //[Optional] Orientation to play slide (for auto play, navigation), 1 horizental, 2 vertical, 5 horizental reverse, 6 vertical reverse, default value is 1
            		$DragOrientation: 2,                                //[Optional] Orientation to drag slide, 0 no drag, 1 horizental, 2 vertical, 3 either, default value is 1 (Note that the $DragOrientation should be the same as $PlayOrientation when $DisplayPieces is greater than 1, or parking position is not 0)
					$HWA: false,										// disable hardware acceleration or image rotates 90* for some reason

            		$ArrowNavigatorOptions: {
                		$Class: $JssorArrowNavigator$,              //[Requried] Class to create arrow navigator instance
                		$ChanceToShow: navDisplay,                               //[Required] 0 Never, 1 Mouse Over, 2 Always
                		$AutoCenter: 0,                                 //[Optional] Auto center arrows in parent container, 0 No, 1 Horizontal, 2 Vertical, 3 Both, default value is 0
                		$Steps: 1,                                       //[Optional] Steps to go for each navigation request, default value is 1
            			$Scale: false							//setting this to false seems to make the arrows disappear :(
            		}
    		};


	     	var that = this;

	     	require(["text!templates/G8C2FoodSubs.html"], function(template) {
				console.log("in require SJB - resolving deferred");
				//this is necessary to ensure the DOM is populated with the containers prior to instantiating the slider objects below.  Otherwise the app will crash.
				renderDeferred.resolve();

	     	});
	     	$.when(renderDeferred).done(function() {
			    console.log("render deferred done");
				var leftSliderObject = new $JssorSlider$("pleftSlider_container", sliderOptions);
				var rightSliderObject = new $JssorSlider$("prightSlider_container", sliderOptions);

				//this causes the scale method to be triggered
				that.model.set({'leftSlider':leftSliderObject, 'rightSlider':rightSliderObject});

				if (that.model.get('leftSliderCurrentIndex') != "not set") {
					leftSliderObject.$GoTo(that.model.get('leftSliderCurrentIndex'));
					that.model.set({'leftSliderCurrentIndex': "not set"});
				} else {
					leftSliderObject.$GoTo(0);
				}
				if (that.model.get('rightSliderCurrentIndex') != "not set") {
					rightSliderObject.$GoTo(that.model.get('rightSliderCurrentIndex'));
					that.model.set({'rightSliderCurrentIndex': "not set"});
				} else {
					rightSliderObject.$GoTo(0);
				}

				// displays text of picture
				rightSliderObject.$On($JssorSlider$.$EVT_PARK, function(slideIndex, fromIndex)
				{
					var portionText = portionsArray[slideIndex][1];
					$("#pictureText").html(portionText);
				});

	     	});  // end deferred

			$(this.el).trigger("create");
            return this;
        },

		/*
		 * This method will scale the slider images to the correct width to fill the width of the device screen. Aspect ratio is preserved and height is based on width
		 */
		// copied from PhotosView.js
		updateScale: function() {
			console.log("updateScale");
            var windowWidth = $(window).width();
            if (windowWidth) {
              	var leftSlider = this.model.get('leftSlider');
             	var rightSlider = this.model.get('rightSlider');

                var windowHeight = $(window).height();

                var scaleWidth = windowWidth;

               	var originalWidth = leftSlider.$GetOriginalWidth();
               	var originalHeight = leftSlider.$GetOriginalHeight();

               	if (originalWidth / windowWidth < originalHeight / windowHeight) {
               	    scaleWidth = Math.ceil(windowHeight / originalHeight * originalWidth);
               	}

				scaleWidth = scaleWidth/2.25;

				leftSlider.$SetScaleWidth(scaleWidth);
                rightSlider.$SetScaleWidth(scaleWidth);
            }
            else {
                 window.setTimeout(this.updateScale, 30);
        	}

		},

        checkAnswer: function() {
			var msg;
			var msgTitle;

          	var foodIndex = this.model.get('leftSlider').$CurrentIndex();
         	var portionIndex = this.model.get('rightSlider').$CurrentIndex();

			var fastFood = foodsArray[foodIndex][0];
			var healthyFood = portionsArray[portionIndex][0];


			if ((foodIndex <= 2) && (portionIndex == 0 || portionIndex == 1 || portionIndex == 2)) {

            msgTitle = "Correct!!";
            msg = healthyFood + " is a healthy alternative to " + fastFood + ".";
			wrongAnswers[foodIndex] = 0;

        }else if ((foodIndex == 3 || foodIndex == 4 || foodIndex == 5) && (portionIndex == 3 || portionIndex == 4 || portionIndex == 5 || portionIndex == 6 || portionIndex == 7)) {

            msgTitle = "Correct!!";
			wrongAnswers[foodIndex] = 0;
			msg = healthyFood + " is a healthy alternative to " + fastFood + ".";

        }else if ((foodIndex == 6) && portionIndex == 6) {

            msgTitle = "Correct!!";
			wrongAnswers[foodIndex] = 0;
			msg = healthyFood + " is a healthy alternative to " + fastFood + ".";

        }else if ((foodIndex == 7 || foodIndex == 8) && portionIndex == 8) {

            msgTitle = "Correct!!";
			wrongAnswers[foodIndex] = 0;
			msg = healthyFood + " is a healthy alternative to " + fastFood + ".";

        }else if ((foodIndex == 9 || foodIndex == 10 || foodIndex == 11 || foodIndex == 12 || foodIndex == 13) && portionIndex == 9) {

            msgTitle = "Correct!!";
			wrongAnswers[foodIndex] = 0;
			msg = healthyFood + " is a healthy alternative to " + fastFood + ".";

        }else if ((foodIndex == 14 || foodIndex == 15 || foodIndex == 16 || foodIndex == 17) && (portionIndex == 10 || portionIndex == 11 || portionIndex == 12 || portionIndex == 13)) {

            msgTitle = "Correct!!";
			wrongAnswers[foodIndex] = 0;
			msg = healthyFood + " is a healthy alternative to " + fastFood + ".";

        }else {

            msgTitle = "Incorrect";
            msg = "Please try again.";
			wrongAnswers[foodIndex]++;
        }



			if ( typeof navigator.notification == 'undefined') {
				alert(msgTitle +"\n" + msg); // fallback for browser or bad plugin
			} else {
				navigator.notification.alert(
					msg,
					null, // callback
					msgTitle, // title
					'OK' // buttonName
				);
			}
        }

    });

    return PortionsView;
});
