define(function(require) {
    var log = require("loglevel"),
        Handlebars = require("handlebars"),
        template = require("text!templates/photos.html"),
        slideHelper = require ("slideHelper"), // required jssor
        slide = require ("slider");	// required jssor

    var compiled_template = Handlebars.compile(template);

	var PhotosView = Backbone.View.extend({
        id: "photosView",

        templateName: "photos.html",

         events: {
             "click #cameraButton": "takePhoto",
             "click #rightDeleteButton": "deleteRightPhoto",
             "click #leftDeleteButton": "deleteLeftPhoto",
             "click #fullScreenDeleteButton": "deleteFullScreenPhoto",
             "click #leftFullScreenButton": "expandLeftPhoto",
             "click #rightFullScreenButton": "expandRightPhoto",
             "click #fullScreenReturnButton": "minimizeFullScreenImage"
         },

		initialize: function() {

			this.listenTo(this.model, 'change:leftSlider', this.updateScale);
			this.listenTo(this.model, 'change:showFullScreenImage', this.render);

			var photosArray = this.model.get ('photos');

			var showExpandedFullScreenImage = this.model.get ('showFullScreenImage');
			var that = this;

			//these helpers show or hide the initial text, full screen image and compare pages
			Handlebars.registerHelper('getFullScreenDisplay', function() {
				if (photosArray.length === 1 || that.model.get ('showFullScreenImage') === true) {
					return "block";
				} else {
					return "none";
				}
			});
			Handlebars.registerHelper('getFullScreenControlsDisplay', function() {
				if (photosArray.length === 1 || that.model.get ('showFullScreenImage') === false) {
					return "block";
				} else {
					return "none";
				}
			});
			Handlebars.registerHelper('getFullScreenExpandedDisplay', function() {
				if (that.model.get ('showFullScreenImage') === true) {
					return "block";
				} else {
					return "none";
				}
			});
			Handlebars.registerHelper('getSlidersDisplay', function() {
				if (photosArray.length > 1 && that.model.get ('showFullScreenImage') === false) {
					return "block";
				} else {
					return "none";
				}
			});

			Handlebars.registerHelper('getPhoneOnlyDisplay', function() {
				if (photosArray.length > 1 && that.model.get ('showFullScreenImage') === false && !isTablet) {
					return "block";
				} else {
					return "none";
				}
			});

			Handlebars.registerHelper('getTextDisplay', function() {
				if (photosArray.length === 0) {
					return "block";
				} else {
					return "none";
				}
			});
			Handlebars.registerHelper('getFullScreenImage', function() {
				if (photosArray.length === 1 || that.model.get ('showFullScreenImage') === true) {
					if (that.model.get ('showFullScreenImage') === true) {
						return cordova.file.documentsDirectory + photosArray[Number(that.model.get('fullScreenImageIndex'))];
					} else {
						return  cordova.file.documentsDirectory + photosArray[0];
					}
				}
			});
			Handlebars.registerHelper('getSliderImages', function() {

				if (photosArray.length > 1 && that.model.get ('showFullScreenImage') === false) {

					var listData = "";
					$.each (photosArray, function(index, value) {

	      				listData = listData + "<div><img u=\"image\" src=\"" + cordova.file.documentsDirectory + value + "\" /></div>";
    			  	});
    			  	return new Handlebars.SafeString (listData);
				}
			});
		},
		/*
		 * This method will scale the slider images to the correct width to fill the width of the device screen. Aspect ratio is preserved and height is based on width
		 */
		updateScale: function() {
			console.log("photoview updateScale");
            var windowWidth = $(window).width();

            if (windowWidth) {

              	var leftSlider = this.model.get('leftSlider');
             	var rightSlider = this.model.get('rightSlider');

                var windowHeight = $(window).height();

                var scaleWidth = windowWidth;

               	var originalWidth = leftSlider.$GetOriginalWidth();
               	var originalHeight = leftSlider.$GetOriginalHeight();

               	if (originalWidth / windowWidth < originalHeight / windowHeight) {
               	    scaleWidth = Math.ceil(windowHeight / originalHeight * originalWidth);
               	}

				scaleWidth = scaleWidth/2.25;

				leftSlider.$SetScaleWidth(scaleWidth);
                rightSlider.$SetScaleWidth(scaleWidth);

            }
            else {
                 window.setTimeout(this.updateScale, 30);
        	}

		},

		render: function() {

			var showImage = this.model.get('showFullScreenImage');

		     this.$el.html(compiled_template(this.model));

		     var photosCount = this.model.get ('photos').length;

		     var initDeferred = $.Deferred();

		     if (photosCount > 1 && this.model.get('showFullScreenImage') === false) {

		     	var navDisplay = 1;
		     	if (isTablet) {
		     		navDisplay = 2;
		     	}

		     	var sliderOptions = {
                		$AutoPlay: false,                                    //[Optional] Whether to auto play, to enable slideshow, this option must be set to true, default value is false
                		$PlayOrientation: 2,                                //[Optional] Orientation to play slide (for auto play, navigation), 1 horizental, 2 vertical, 5 horizental reverse, 6 vertical reverse, default value is 1
                		$DragOrientation: 2,                                //[Optional] Orientation to drag slide, 0 no drag, 1 horizental, 2 vertical, 3 either, default value is 1 (Note that the $DragOrientation should be the same as $PlayOrientation when $DisplayPieces is greater than 1, or parking position is not 0)
						$HWA: false,										// disable hardware acceleration or image rotates 90* for some reason

                		$ArrowNavigatorOptions: {
                    		$Class: $JssorArrowNavigator$,              //[Requried] Class to create arrow navigator instance
                    		$ChanceToShow: navDisplay,                               //[Required] 0 Never, 1 Mouse Over, 2 Always
                    		$AutoCenter: 0,                                 //[Optional] Auto center arrows in parent container, 0 No, 1 Horizontal, 2 Vertical, 3 Both, default value is 0
                    		$Steps: 1,                                       //[Optional] Steps to go for each navigation request, default value is 1
                			$Scale: false							//setting this to false seems to make the arrows disappear :(
                		}
        		};


		     	var that = this;

		     	require(["text!templates/PhotosTemplate.html"], function(template) {

					//this is necessary to ensure the DOM is populated with the containers prior to instantiating the slider objects below.  Otherwise the app will crash.
					initDeferred.resolve();

		     	});
		     	$.when(initDeferred).done(function() {

					var leftSliderObject = new $JssorSlider$("leftSlider_container", sliderOptions);
					var rightSliderObject = new $JssorSlider$("rightSlider_container", sliderOptions);

					//this causes the scale method to be triggered
					that.model.set({'leftSlider':leftSliderObject, 'rightSlider':rightSliderObject});

					if (that.model.get('leftSliderCurrentIndex') != "not set") {
						leftSliderObject.$GoTo(that.model.get('leftSliderCurrentIndex'));
						that.model.set({'leftSliderCurrentIndex': "not set"});
					} else {
						leftSliderObject.$GoTo(0);
					}
					if (that.model.get('rightSliderCurrentIndex') != "not set") {
						rightSliderObject.$GoTo(that.model.get('rightSliderCurrentIndex'));
						that.model.set({'rightSliderCurrentIndex': "not set"});
					}else {
						rightSliderObject.$GoTo(photosCount-1);
					}
		     	});
		     }

		     $(this.el).trigger("create");
            return this;

		},

		takePhoto: function() {

			that = this;
			var deferredPhotos = $.Deferred();

			//prompt user for camera or existing photos, use to set pictureSourceType
			navigator.notification.confirm(
    			'', // message
     			onConfirm,            // callback to invoke with index of button pressed
    			'Take a photo of yourself to measure your progress',           // title
    			['Take Photo','Choose Existing', 'Cancel']     // buttonLabels
			);

			var photoSource;
			function onConfirm(buttonIndex) {
				if (buttonIndex === 1) {
					photoSource = Camera.PictureSourceType.CAMERA;
					deferredPhotos.resolve();
				} else if (buttonIndex === 2) {
					photoSource = Camera.PictureSourceType.PHOTOLIBRARY;
					deferredPhotos.resolve();
				} else if (buttonIndex === 3) {
					console.log ("cancel this stuff");
				}
			}

			 $.when(deferredPhotos).done(function() {

				 if (typeof navigator.camera != "undefined") {
					navigator.camera.getPicture(onSuccess, onFail, { quality: 50, destinationType: Camera.DestinationType.DATA_URI, sourceType : photoSource });
				} else {
					console.log ("Camera is only supported on device.  Please run on a valid device");
				}

			 });

			function onSuccess(imageURI) {

				deferredMove = $.Deferred();
				//move photo out of temp dir and into a persistent directory
				that.movePhoto(imageURI);

				$.when(deferredMove).done (function() {
					that.render();
				});
			}
			function onFail(message) {
    			 console.log('Failed because: ' + message);
			}
		},


		movePhoto: function (file) {

    		window.resolveLocalFileSystemURL(file, resolveOnSuccess, resOnError);

			//Callback function when the file system uri has been resolved
			function resolveOnSuccess(entry){

    			var d = new Date();
    			var n = d.getTime();
    			//new file name
    			var newFileName = n + ".jpg";
    			var myFolderApp = "localPhotos";

    			window.requestFileSystem(LocalFileSystem.PERSISTENT, 0, function(fileSys) {
    			//The folder is created if doesn't exist
    			fileSys.root.getDirectory( myFolderApp,
                    {create:true, exclusive: false},
                    function(directory) {
                        entry.moveTo(directory, newFileName,  successMove, resOnError);
                    },
                    resOnError);
                    },
    				resOnError);
			}

			//Callback function when the file has been moved successfully - inserting the complete path
			function successMove(entry) {

				//this could be cleaned up
				var tempArray = new Array();
				tempArray = that.model.get ('photos');
				tempArray.push (entry.fullPath);
				that.model.set ({photos: tempArray});

				that.model.save();

				deferredMove.resolve();
			}

			function resOnError(error) {
    			alert(error.code);
			}
		},

		expandLeftPhoto: function() {

			var leftSlider = this.model.get ('leftSlider');
			this.expandPhoto(leftSlider.$CurrentIndex());

		},
		expandRightPhoto: function() {

			var rightSlider = this.model.get ('rightSlider');
			this.expandPhoto(rightSlider.$CurrentIndex());

		},
		expandPhoto: function (index) {

			var rightSlider = this.model.get ('rightSlider');
			var leftSlider = this.model.get ('leftSlider');

			var photosArray = this.model.get ('photos');
			var path = cordova.file.documentsDirectory + photosArray[Number(index)];

			this.model.set ({leftSliderCurrentIndex:leftSlider.$CurrentIndex(), rightSliderCurrentIndex:rightSlider.$CurrentIndex() });

			this.model.set({fullScreenImageIndex:index});
			this.model.set({showFullScreenImage:true});

		},
		minimizeFullScreenImage: function() {

			this.model.set({fullScreenImageIndex:0});
			this.model.set({showFullScreenImage:false});
		},

		deleteRightPhoto: function() {

			var rightSlider = this.model.get ('rightSlider');
			this.deletePhoto(rightSlider.$CurrentIndex());
		},
		deleteLeftPhoto: function() {
			var leftSlider = this.model.get ('leftSlider');
			this.deletePhoto(leftSlider.$CurrentIndex());
		},
		//this is only used when there is only one photo available
		deleteFullScreenPhoto: function() {
			this.deletePhoto('0');
		},

		deletePhoto: function(index) {

			var that = this;

			navigator.notification.confirm(
    			'The photo will not be deleted from your camera roll', // message
     			onConfirmDelete,            // callback to invoke with index of button pressed
    			'Delete this photo?',           // title
    			['Delete', 'Cancel']     // buttonLabels
			);

			deferredDeletePhoto = $.Deferred();

			var confirmDelete;
			function onConfirmDelete(buttonIndex) {

				if (buttonIndex === 1) {

					that.removePhotoFromDisk (index);

				} else if (buttonIndex === 2) {
					deferredDeletePhoto.reject();
					console.log ("just cancel");
				}
			}

			$.when(deferredDeletePhoto).done (function() {
				that.render();
			});

		},
		removePhotoFromDisk: function (index) {

			var tempArray = new Array();
			tempArray = this.model.get ('photos');

			var that = this;

			var file = cordova.file.documentsDirectory + tempArray[Number(index)];

			window.resolveLocalFileSystemURL(file, resolveOnSuccess, resOnError);

			function resolveOnSuccess(entry){

				entry.remove(removeSuccess, removeFail);

				function removeSuccess() {
					removed = tempArray.splice(Number(index), 1);
					that.model.set ({photos: tempArray});
					that.model.save();

					deferredDeletePhoto.resolve();
				}
				function removeFail() {
					console.log ("the file removal failed");
					deferredDeletePhoto.resolve();

				}
			}

			function resOnError () {
				console.log ("error resolving local file system");
				deferredDeletePhoto.resolve();

			}
		}
	});
	return PhotosView;
});
