define(function(require) {
    var log = require("loglevel"),
	    Handlebars = require("handlebars"),
        UserData = require("models/UserData"),
        GuidesCollection = require("collections/allGuides"),
        Summary = require("models/GuideSummaryModel"),
        pdfHelper = require("views/pdfHelperFunctions"),
        pdfGenerator = require("utilities/pdfGenerator"),
        template = require("text!templates/guideSummaryProgressReview.html");

    var compiled_template = Handlebars.compile(template);

    var pdfUrl = null;
    

    var GuideSummaryView = Backbone.View.extend({

        id: "SingleGuideSummaryView",

        events: {
            "click #summaryPDF": "viewPDF",
            "click #emailPDF": "emailPDF"
        },

		initialize: function(args) {

            this.model = GuidesCollection.get(args.guideId);
            var model = this.model;


            
            Handlebars.registerHelper('getItems', function(type, summary) {
            	            	
            	var arrayName = type + 'PR';
            	var dataArray = summary[arrayName] || [];
            	console.log ("array name: " + arrayName);
            	var dataString = "";
            	$.each (dataArray, function (index, value) {
            		dataString = dataString + '<li style="white-space:normal;">' + value + '</li>';
            	});
            	
            	if (dataString === "") {
            		dataString = "<li>None</li>";
            	}
            	
            	return new Handlebars.SafeString(dataString);
            	
            });
            
            Handlebars.registerHelper('getActivityGoalAnswer', function(summary) {
                      	console.log ("getActivityGoalAnswer");

           		//this catches the case where the user left the default value
           		var returnString = "No";
           		var value = summary["reachingActivityGoalsPR"]; 
           		if (value === "Yes") {
           			returnString = "Yes";
           		}           
            	return returnString;       	
            });

            Handlebars.registerHelper('getDietGoalAnswer', function(summary) {
            	console.log ("getDietGoalAnswer");
            	var returnString = "No";
           		var value = summary["reachingDietGoalsPR"]; 
           		if (value === "Yes") {
           			returnString = "Yes";
           		}            	        
            	return returnString;
            });        

			// we could check for existing PDF and only generate once
			this.generatePDF();
		},

        render: function() {
            this.$el.html(compiled_template( this.model.toJSON() ));
        },


        viewPDF: function() {
        	console.log("viewPDF url: ", pdfUrl);
			pdfHelper.openPDF(pdfUrl);
        },

        emailPDF: function() {
        	console.log("emailPDF not implemented yet");

			this.generatePDF();

        	// TODO copy email stuff from EE NoteDetailPageView
        },

        generatePDF: function() {
        	console.log("generatePDF");


			var summaries = this.model.get("summaries");
			console.log("guide summary: ", JSON.stringify(summaries));
// 			var summary = null;

// 			if (summaries.length) summary = summaries[0];  // get first summary object for current checkin
			var model = this.model;

			// Since images are loaded asyncronously, we must wait to create
			// the pdf until we actually have the image.
			// The callback for this will create the PDF.
			var getImageFromUrl = function(url, callback) {
				var img = new Image();

				img.onError = function() {
					alert('Cannot load image: "'+url+'"');
				};
				img.onload = function() {
					callback(img);
				};
				img.src = url;
			};

			// This is the callback to create the PDF with the image data after it's loaded.
			var createPDF = function(imgData) {
				var doc = new jsPDF('p','mm','letter');

				$.each(summaries, function(idx, summary) {

					// header

					// SJB "rotating" image at angle 0 draws with transparency (rounded corners) otherwise it's black square corners
					// Rotate Image - new feature as of 2014-09-20
					doc.addImage({
						imageData : imgData,
						angle     : 0,
						x         : 10,
						y         : 10,
						w         : 16,
						h         : 16
					});

					doc.setFont("helvetica");
					doc.setFontType("bold");
					doc.setFontSize(10);
					doc.text(88, 20, 'MOVE! Coach Mobile');
					doc.line(5, 30, 205, 30); // horizontal line

					// body

					var txt = "Guide " + model.id + " Progress Check-In";
					doc.setFontSize(16);
					doc.text(10, 40, txt);

					var size = 12;  // used for text and line split calculation below
					doc.setFontSize(size);
					doc.setFontType("normal");

					doc.text(10, 55, 'Date Completed:');
					doc.text(60, 55, summary.dateCompleted);

					var x1 = 20;	// x pos of indent
					var value, arrayData;

					// for splitting lines
					var lines;
					var sizeOffset = (size / 72) * 25.4; // inches to mm
					var listSpacing = 4; // space between items in list
					var xListIdx = 20;


					doc.text(10, 65, 'Have you been reaching your weekly activity goals?');
           			value = summary.reachingActivityGoalsPR;
	           		if (value !== "Yes") {
	           			value = "No";
    	       		}           
					doc.text(x1, 70, value);

					var y = 80;
					doc.text(10, y, 'What changes have you made to be more active?');

					y += 5;
					arrayData = _.isEmpty(summary.activityChangesPR) ? ["None"] : summary.activityChangesPR;
					$.each(arrayData, function(idx, change) {
						lines = doc.splitTextToSize(change, 170);
						doc.text(xListIdx, y, lines);
						y += (lines.length + 0.5) * sizeOffset +listSpacing;
					});

					doc.text(10, y, 'How will you improve your activity goal progress?');

					y += 5;
					arrayData = _.isEmpty(summary.activityGoalChangesPR) ? ["None"] : summary.activityGoalChangesPR;
					$.each(arrayData, function(idx, change) {
						lines = doc.splitTextToSize(change, 170);
						doc.text(xListIdx, y, lines);
						y += (lines.length + 0.5) * sizeOffset +listSpacing;
					});

					doc.text(10, y, 'Have you been reaching your weekly diet goals?');
           			value = summary.reachingDietGoalsPR;
	           		if (value !== "Yes") {
	           			value = "No";
    	       		}           
					y += 5;
					doc.text(x1, y, value);

					y += 10;
					doc.text(10, y, 'What changes have you made to make healthy food choices?');

					y += 5;
					arrayData = _.isEmpty(summary.dietChangesPR) ? ["None"] : summary.dietChangesPR;
					$.each(arrayData, function(idx, change) {
						lines = doc.splitTextToSize(change, 170);
						doc.text(xListIdx, y, lines);
						y += (lines.length + 0.5) * sizeOffset +listSpacing;
					});

					doc.text(10, y, 'How will you improve your diet goal progress?');

					y += 5;
					arrayData = _.isEmpty(summary.dietGoalChangesPR) ? ["None"] : summary.dietGoalChangesPR;
					$.each(arrayData, function(idx, change) {
						lines = doc.splitTextToSize(change, 170);
						doc.text(xListIdx, y, lines);
						y += (lines.length + 0.5) * sizeOffset +listSpacing;
					});


					// new page
					if ( idx < summaries.length -1 )
					{
						doc.addPage();
					}
				});
				

                // Define a callback to handle successfull access to the file system.
                var onFileSystemSuccess = function(fileSystem) {

                    // Get generated pdf file.
                    var filename = "summaryGuide" + model.id + "Review.pdf";
                    fileSystem.root.getFile(filename, {
                        create: true,
                        exclusive: false
                    }, gotFileEntry, fail);
                };

                // Define a callback to handle successfull retreival of a file.
                var gotFileEntry = function(fileEntry) {
                    log.debug("fileEntry: " + fileEntry);
                    log.debug("fileEntry.toURL: " + fileEntry.toURL());
                    console.log(".....fileEntry: " + fileEntry);
                    console.log(".....fileEntry.toURL: " + fileEntry.toURL());
					pdfUrl = fileEntry.toURL(); // for viewing later
                    fileEntry.createWriter(gotFileWriter, fail);
                };

                // Define a callback to handle successfull creation of a file writer.
                var gotFileWriter = function(writer) {
                    // Define a callback to handle a successful write to the filesystem.
                    writer.onwriteend = function(evt) {
/*
                        // Done writing the file, so now include it as an email attachment.
                        window.requestFileSystem(LocalFileSystem.PERSISTENT, 0, function(fileSystem) {
                            fileSystem.root.getFile("guidesummary.pdf", {
                                create: false,
                                exclusive: false
                            }, function(fileEntry) {
                                var isHtml = false;
                                // window.plugins.emailComposer.showEmailComposer("Subject goes here", "Content goes here.", ["to recipients go here"], ["cc recipients go here"], ["bcc recipients go here"], isHtml, ['/storage/emulated/0/exposureEd_note.pdf'], []);
                                window.plugins.emailComposer.showEmailComposer("", "", [""], [""], [""], isHtml, [fileEntry.nativeURL.replace(/file:\/\//, "")], []);
                            }, fail);
                        }, fail);
                  */
                    };

                    // Save our generated pdf document to the file system.
		            var blob = doc.output('blob');
                    writer.write(blob);
                };

                // Define a callback to handle any errors during access to the file system.
                var fail = function(error) {
                    log.error(error.code);
                    console.log("**=*=*=*=*=*=*=* error: " + error.code);
                };


                // Request access to the file system.
				if ("undefined" == typeof LocalFileSystem )
				{
// 		            doc.output('datauri');
                    var filename = "summaryGuide" + model.id + "Review.pdf";
					doc.save(filename);	
				}
				else
				{
					window.requestFileSystem(LocalFileSystem.PERSISTENT, 0, onFileSystemSuccess, fail);
	            }
			};

			getImageFromUrl('images/icons/bullhornWithBorder@2x.png', createPDF);        	
        }

    });

    return GuideSummaryView;
});



