define(function(require) {
    var log = require("loglevel"),
	    Handlebars = require("handlebars"),
        UserData = require("models/UserData"),
        GuidesCollection = require("collections/allGuides"),
        Summary = require("models/GuideSummaryModel"),
        pdfHelper = require("views/pdfHelperFunctions"),
        pdfGenerator = require("utilities/pdfGenerator"),
        template = require("text!templates/guideSummary.html");

    var compiled_template = Handlebars.compile(template);

    var pdfUrl = null;
    

    var GuideSummaryView = Backbone.View.extend({

        id: "SingleGuideSummaryView",

        events: {
            "click #summaryPDF": "viewPDF",
            "click #emailPDF": "emailPDF"
        },

		initialize: function(args) {

			Handlebars.registerHelper('if_odd', function(conditional, options) {
			  if((conditional % 2) == 0) {
				return options.inverse(this);
			  } else {
				return options.fn(this);;
			  }
			});

			this.model = GuidesCollection.get(args.id);

			// we could check for existing PDF and only generate once
			this.generatePDF();
		},

        render: function() {
            this.$el.html(compiled_template( this.model.toJSON() ));
        },


        viewPDF: function() {
        	console.log("viewPDF url: ", pdfUrl);
			pdfHelper.openPDF(pdfUrl);

/*
			// using callbacks to try and resolve timing discrepancy so we view only after generating, but doesn't work
			var generateAndViewPDF = function(ctx, viewFunction) {

				ctx.generatePDF();

				viewFunction(pdfUrl);

			}
			var viewIt = function(url) {
				console.log("viewing url: ", url);
				pdfHelper.openPDF(url);
			}

			generateAndViewPDF(this, viewIt);
*/
/*
			this.generatePDF();

//         	var url = this.model.get("summaries").pdfFileUrl;
        	console.log("viewing url: ", pdfUrl);
			pdfHelper.openPDF(pdfUrl);
*/
        },

        emailPDF: function() {
        	console.log("emailPDF not implemented yet");

			this.generatePDF();

        	// TODO copy email stuff from EE NoteDetailPageView
        },

        generatePDF: function() {
        	console.log("generatePDF");
			var summaries = this.model.get("summaries");
			console.log("gv summary: ", JSON.stringify(summaries));
			var model = this.model;

			// Since images are loaded asyncronously, we must wait to create
			// the pdf until we actually have the image.
			// The callback for this will create the PDF.
			var getImageFromUrl = function(url, callback) {
				var img = new Image();

				img.onError = function() {
					alert('Cannot load image: "'+url+'"');
				};
				img.onload = function() {
					callback(img);
				};
				img.src = url;
			};

			// This is the callback to create the PDF with the image data after it's loaded.
			var createPDF = function(imgData) {
				var doc = new jsPDF('p','mm','letter');

				$.each(summaries, function(idx, summary) {

					// header
	
					// SJB "rotating" image at angle 0 draws with transparency (rounded corners) otherwise it's black square corners
					// Rotate Image - new feature as of 2014-09-20
					doc.addImage({
						imageData : imgData,
						angle     : 0,
						x         : 10,
						y         : 10,
						w         : 16,
						h         : 16
					});
	
					doc.setFont("helvetica");
					doc.setFontType("bold");
					doc.setFontSize(10);
					doc.text(88, 20, 'MOVE! Coach Mobile');
					doc.line(5, 30, 205, 30); // horizontal line
	
					// body
	
					var txt = "Guide " + model.id + " Summary Report - " + model.get("title");
					doc.setFontSize(16);
					doc.text(10, 40, txt);
					
					var size = 12;  // used for text and line split calculation below
					doc.setFontSize(size);
					doc.setFontType("normal");
	
					doc.text(10, 55, 'Date Completed:');
					doc.text(60, 55, summary.dateCompleted);
	
					var x1 = 20;	// x pos of first label column
					var xv1 = 50; // x pos of first value column
					var x2 = 120;	// x pos of second label column
					var xv2 = 150; // x pos of second value column
					doc.text(10, 65, 'My Data:');
					doc.text(x1, 75, 'Weight:');
					doc.text(xv1, 75, '' + summary.weight + ' lbs (' + summary.weightLost + ')');
					doc.text(x1, 85, 'Loss Goal:');
					doc.text(xv1, 85, '' + summary.lossGoal + ' lbs (' + summary.lossGoalPct + '%)');
					doc.text(x1, 95, 'Calorie Goal:');
					var calText = '' + summary.calorieGoal + ' Calories/Day';
					if ( summary.mca != 0 ) {
						calText += '  (Includes ' + summary.mca + ' Calorie adjustment)';
					}
					doc.text(xv1, 95, calText);
					if ( summary.bmi > 0 ) {
						doc.text(x2, 75, 'BMI:');
						doc.text(xv2, 75, '' + summary.bmi);
					}
					doc.text(x2, 85, 'Loss Rate:');
					doc.text(xv2, 85, '' + summary.lossRate + ' lbs/Week');
	
	
					// for splitting lines
					var lines;
					var sizeOffset = (size / 72) * 25.4; // inches to mm
					var listSpacing = 5; // space between items in list
					var xListIdx = 20;
					var xListItem = 26;
	
	
					var y = 105;
					doc.text(10, y, 'Key Points:');
	
					y += 10;
					$.each(summary.keyPoints, function(idx, point) {
						lines = doc.splitTextToSize(point, 170);
						doc.text(xListIdx, y, '' + (idx +1)).text(xListItem, y, lines);
						y += (lines.length + 0.5) * sizeOffset +listSpacing;
					});
	
					doc.text(10, y, 'Activity SMART Goals:');
					y += 10;
					
					if ( summary.paSmartGoal1 ) {
						lines = doc.splitTextToSize(summary.paSmartGoal1, 170);
					} else lines = [''];
					doc.text(xListIdx, y, "1").text(xListItem, y, lines);
					y += (lines.length + 0.5) * sizeOffset +listSpacing;
					if ( summary.paSmartGoal2 ) {
						lines = doc.splitTextToSize(summary.paSmartGoal2, 170);
					} else lines = [''];
					doc.text(xListIdx, y, "2").text(xListItem, y, lines);
					y += (lines.length + 0.5) * sizeOffset +listSpacing;
	
					doc.text(10, y, 'Dietary SMART Goals:');
					y += 10;

					if ( summary.dietSmartGoal1 ) {
						lines = doc.splitTextToSize(summary.dietSmartGoal1, 170);
					} else lines = [''];
					doc.text(xListIdx, y, "1").text(xListItem, y, lines);
					y += (lines.length + 0.5) * sizeOffset +listSpacing;
	
					if ( summary.dietSmartGoal2 ) {
						lines = doc.splitTextToSize(summary.dietSmartGoal2, 170);
					} else lines = [''];
					doc.text(xListIdx, y, "2").text(xListItem, y, lines);
	
					 
					// new page
					if ( idx < summaries.length -1 )
					{
						doc.addPage();
					}
				});


                // Define a callback to handle successfull access to the file system.
                var onFileSystemSuccess = function(fileSystem) {

                    // Get generated pdf file.
                    var filename = "summaryGuide" + model.id + ".pdf";
                    fileSystem.root.getFile(filename, {
                        create: true,
                        exclusive: false
                    }, gotFileEntry, fail);
                };

                // Define a callback to handle successfull retreival of a file.
                var gotFileEntry = function(fileEntry) {
                    log.debug("fileEntry: " + fileEntry);
                    log.debug("fileEntry.toURL: " + fileEntry.toURL());
                    console.log(".....fileEntry: " + fileEntry);
                    console.log(".....fileEntry.toURL: " + fileEntry.toURL());
					pdfUrl = fileEntry.toURL(); // for viewing later
                    fileEntry.createWriter(gotFileWriter, fail);
                };

                // Define a callback to handle successfull creation of a file writer.
                var gotFileWriter = function(writer) {
                    // Define a callback to handle a successful write to the filesystem.
                    writer.onwriteend = function(evt) {
/*
                        // Done writing the file, so now include it as an email attachment.
                        window.requestFileSystem(LocalFileSystem.PERSISTENT, 0, function(fileSystem) {
                            fileSystem.root.getFile("guidesummary.pdf", {
                                create: false,
                                exclusive: false
                            }, function(fileEntry) {
                                var isHtml = false;
                                // window.plugins.emailComposer.showEmailComposer("Subject goes here", "Content goes here.", ["to recipients go here"], ["cc recipients go here"], ["bcc recipients go here"], isHtml, ['/storage/emulated/0/exposureEd_note.pdf'], []);
                                window.plugins.emailComposer.showEmailComposer("", "", [""], [""], [""], isHtml, [fileEntry.nativeURL.replace(/file:\/\//, "")], []);
                            }, fail);
                        }, fail);
                  */
                    };

                    // Save our generated pdf document to the file system.
		            var blob = doc.output('blob');
                    writer.write(blob);
                };

                // Define a callback to handle any errors during access to the file system.
                var fail = function(error) {
                    log.error(error.code);
                    console.log("**=*=*=*=*=*=*=* error: " + error.code);
                };

                // Request access to the file system.
				if ("undefined" == typeof LocalFileSystem )
				{
// 		            doc.output('datauri');
                    var filename = "summaryGuide" + model.id + ".pdf";
					doc.save(filename);	
				}
				else
				{
					window.requestFileSystem(LocalFileSystem.PERSISTENT, 0, onFileSystemSuccess, fail);
	            }
			};

			getImageFromUrl('images/icons/bullhornWithBorder@2x.png', createPDF);        	
        }
        

    });

    return GuideSummaryView;
});



