define(function(require) {
    var log = require("loglevel"),
        mockjax = require("mockjax");

    var WeightsCollection = Backbone.Collection.extend({
        url: 'http://localhost:9000/content/weights',

        model: Backbone.Model,

        // Used to allow others to wait for the collection to be populated.
        deferred: $.Deferred(),

        initialize: function() {
            // Get guide information from server.
            this.fetch({
                reset: true
            });

            // The reset event is fired when the collection has been reset. It's now
            // safe to notify anyone waiting on the deferred since the collection is
            // populated.
            this.on("reset", function(e) {
                this.deferred.resolve();
            });
        },

        /**
         * Method (callback) in response to a 'fetch' or 'save' request. Parse is called
         * whenever a model's data is returned by the server in fetch and save method calls.
         *
         * @method parse
         * @param response JSON response from a server fetch or save request.
         */
        parse: function(response) {
            // log.debug(JSON.stringify(response));
            return response.weights;
        }
    });

    // TESTING ONLY!
    // Does the same thing as the code above. Comment out this code to actually retrieve the data from a webservice.
    $.mockjax({
        logging: false,
        url: 'http://localhost:9000/content/weights',
        contentType: 'text/json',
        proxy: 'content/weights.json'
    });

    return new WeightsCollection();
});