define(function(require) {
    var log = require("loglevel"),
        Handlebars = require("handlebars"),
        pdfHelper = require("views/pdfHelperFunctions"),
        EventData = require("models/ChainOfEventsModel"),
        template = require("text!templates/G10C2ChainOfEvents-1.html");

    // Compile the template once.
    var compiled_template = Handlebars.compile(template);
    var editingIndex = -1;

    var G10C2ChainOfEvents1View = Backbone.View.extend({
        // Set the id attribute on the div.
        id: "G10C2ChainOfEvents1View",

		model: EventData,

		initialize: function() {
		},

        events: {

            "click #exampleButton": "exampleButtonTapped",
            "click #resetButton": "resetChainData",

            'change #chainofevents': function(ev){this.fieldChange(ev, "chainofevents", "eventsListView", "eventChain");},
            'change #coeproblem': 'problemChanged',

            'swipeleft ul#eventsListView li#deletableCells': function(ev){this.getIndexAndRemove(ev, "eventChain");},
            'swiperight ul#eventsListView li#deletableCells': function(ev){this.getIndexAndRemove(ev, "eventChain");},
            'click ul#eventsListView li#deletableCells': function(ev){this.getIndexAndEdit(ev, "eventChain");},

        },

        render: function() {

            $(this.el).html(compiled_template(EventData.toJSON()));

            return this;
        },

       	fieldChange: function (ev, textFieldName, listName, arrayName ) {
			console.log("fieldChange");

       		setTimeout(function(){

				var textFieldID = "#"+textFieldName;
				var listID = "#"+listName;
				var value = $(textFieldID).val();

				if ( value == "" ) return;

				if (editingIndex > 0) 
				{
					EventData.replaceEventNameInList(arrayName, editingIndex -1, value);
					$('.highlight').text(value);
					$('.highlight').removeClass('highlight');
					editingIndex = -1;
				}
				else 
				{
					EventData.addEventItemToList(arrayName, value);
					$('<li id="deletableCells">').append(value).appendTo( $(listID) );
				}
				$(textFieldID).val('');
				$(listID).listview("refresh");

			}, 100);
       	},

		problemChanged: function() {
			var problemDetail = $("#coeproblem").val();
			EventData.set("problemDescription", problemDetail);
			EventData.save();
		},

		getIndexAndRemove: function (ev, arrayName) {
			var selectedIndex = $(ev.currentTarget).index();
			var titleString = "Are you sure you want to delete " + $(ev.currentTarget).text();

			function onConfirm(buttonIndex) {
  				if (buttonIndex === 1) {
					//this accounts for the odd way that JQuery returns indexes starting at 1 instead of 0
					selectedIndex = selectedIndex-1;

					var success = false;
					success = EventData.removeItemFromList(arrayName, selectedIndex);

					if (success) {
						$(ev.currentTarget).remove();
					}
				}
			}

			if ( typeof navigator.notification == 'undefined') {
				if (confirm(titleString)) onConfirm(1);
			} else {
				navigator.notification.confirm(
					' ', // message
					onConfirm,            // callback to invoke with index of button pressed
					titleString,           // title
					['Yes','No']     // buttonLabels
				);
			}
		},
		
		// toggle editing of current list item
		getIndexAndEdit: function (ev, arrayName) {
			console.log("getIndexAndEdit");

			// makes user force toggle to stop editing - didn't like it
// 			var selectedIndex = $(ev.currentTarget).index();
// 			if (editingIndex > 0 && selectedIndex != editingIndex) return;


			if ( $(ev.currentTarget).hasClass('highlight') ) {
				// disable editing
				editingIndex = -1;
				$(ev.currentTarget).removeClass('highlight');
				$("#chainofevents").val('');
			}
			else {
				// enable editing
				var selectedIndex = $(ev.currentTarget).index();
				var editText = $(ev.currentTarget).text();

				editingIndex = selectedIndex;

				$('.highlight').removeClass('highlight');
				$(ev.currentTarget).addClass('highlight');
				$("#chainofevents").val(editText);
				$("#chainofevents").focus();
			}
		},
		
        exampleButtonTapped: function (ev) {
        	pdfHelper.openHandoutsPDF(ev);
        },

        resetChainData: function (ev) {
        	var confirmString = "Do you want to delete this chain of events data and enter a new Chain of Events?";

			function onConfirmReset(buttonIndex) {
				console.log("onConfirmReset:  button: " + buttonIndex);
  				if (buttonIndex === 1) {
  					console.log("reset data");

					EventData.set("problemDescription", "");
					EventData.set("eventChain", []);
					EventData.save();

					// wants to use slide for transition, so change temporarily
					var xitn = $.mobile.changePage.defaults.transition;
					console.log("xitn:" + xitn);
					$.mobile.changePage.defaults.transition = "fade";
					Backbone.history.loadUrl();
	                $.mobile.changePage.defaults.transition = xitn;
				}
			}

			if ( typeof navigator.notification == 'undefined') {
				if (confirm(confirmString)) onConfirmReset(1);
			} else {
				navigator.notification.confirm(
					confirmString, // message
					onConfirmReset,            // callback to invoke with index of button pressed
					"Confirm",           // title
					['Delete','Cancel']     // buttonLabels
				);
			}
        }


    });

    return G10C2ChainOfEvents1View;
});
