define(function(require) {
    var log = require("loglevel"),
        Handlebars = require("handlebars"),
        ProgressData = require("models/ProgressReviewModel"),
        template = require("text!templates/progressReview.html");

    // Compile the template once.
    var compiled_template = Handlebars.compile(template);

    // The view for Guide 1 Quesionnaire
    var ProgressReviewView = Backbone.View.extend({
        // Set the id attribute on the div.
        id: "progressReviewView",

		model: ProgressData,

		initialize: function(args) {

			this.isClearing = false;
			this.guideNum = args.guide;
			
			// ProgressData.set ("reachingActivityGoals" + this.guideNum, "No");
			// ProgressData.set ("reachingDietGoals" + this.guideNum, "No");
			console.log ("args: " + args.guide);
		},

        events: {

            'click .clearable>.ui-input-has-clear>.ui-input-clear': function(ev) {console.log ("generic clear was tapped"); this.isClearing=true;},

            'change #activityChanges': function(ev){this.fieldChange(ev, "activityChanges", "activeChangesListView", "activityChanges" + this.guideNum);},
            'change #dietChanges': function(ev){this.fieldChange(ev, "dietChanges", "dietChangesListView", "dietChanges" + this.guideNum);},
            'change #activityGoalProgress': function(ev){this.fieldChange(ev, "activityGoalProgress", "activityGoalProgressListView", "activityGoalChanges" + this.guideNum);},
            'change #dietGoalProgress':  function(ev){this.fieldChange(ev, "dietGoalProgress", "dietGoalProgressListView", "dietGoalChanges" + this.guideNum);},

            'change #reachingActivityGoalsFieldSet': 'reachingActivityGoalsFieldSetChanged',
            'change #reachingDietGoalsFieldSet': 'reachingDietGoalsFieldSetChanged',

			'swipeleft ul#activeChangesListView li#deletableCells': function(ev){this.getIndexAndRemove(ev, "activityChanges" + this.guideNum);},
            'swiperight ul#activeChangesListView li#deletableCells': function(ev){this.getIndexAndRemove(ev, "activityChanges" + this.guideNum);},

            'swipeleft ul#dietChangesListView li#deletableCells': function(ev){this.getIndexAndRemove(ev, "dietChanges" + this.guideNum);},
            'swiperight ul#dietChangesListView li#deletableCells': function(ev){this.getIndexAndRemove(ev, "dietChanges" + this.guideNum);},

            'swipeleft ul#activityGoalProgressListView li#deletableCells': function(ev){this.getIndexAndRemove(ev, "activityGoalChanges" + this.guideNum);},
            'swiperight ul#activityGoalProgressListView li#deletableCells': function(ev){this.getIndexAndRemove(ev, "activityGoalChanges" + this.guideNum);},

            'swipeleft ul#dietGoalProgressListView li#deletableCells': function(ev){this.getIndexAndRemove(ev, "dietGoalChanges" + this.guideNum);},
            'swiperight ul#dietGoalProgressListView li#deletableCells': function(ev){this.getIndexAndRemove(ev, "dietGoalChanges" + this.guideNum);}

        },

        render: function() {
            $(this.el).html(compiled_template(ProgressData.toJSON()));

            var reachingActivityGoals = ProgressData.get ("reachingActivityGoals" + this.guideNum);
            if (reachingActivityGoals === 'Yes') {
            	this.$('#reachingActivityGoalsFieldSetYes').attr('checked', true);
            } else {
            	this.$('#reachingActivityGoalsFieldSetNo').attr('checked', true);
            }

            var reachingDietGoals = ProgressData.get ("reachingDietGoals" + this.guideNum);
            if (reachingDietGoals === 'Yes') {
            	this.$('#reachingDietGoalsFieldSetYes').attr('checked', true);
            } else {
            	this.$('#reachingDietGoalsFieldSetNo').attr('checked', true);
            }

            var self = this;

            var activityChanges = ProgressData.get ("activityChanges" + this.guideNum);
            $.each( activityChanges, function( key, value ) {
				$('<li id="deletableCells" style="white-space:normal;">').append(value).appendTo(self.$('#activeChangesListView'));
			});

            var dietChanges = ProgressData.get ("dietChanges" + this.guideNum);
            $.each( dietChanges, function( key, value ) {
				$('<li id="deletableCells" style="white-space:normal;">').append(value).appendTo(self.$('#dietChangesListView'));
			});

			var activityGoalChanges = ProgressData.get ("activityGoalChanges" + this.guideNum);
            $.each( activityGoalChanges, function( key, value ) {
				$('<li id="deletableCells" style="white-space:normal;">').append(value).appendTo(self.$('#activityGoalProgressListView'));
			});

			var dietGoalChanges = ProgressData.get ("dietGoalChanges" + this.guideNum);
            $.each( dietGoalChanges, function( key, value ) {
				$('<li id="deletableCells" style="white-space:normal;">').append(value).appendTo(self.$('#dietGoalProgressListView'));
			});

            return this;
        },

       	fieldChange: function (event, textFieldName, listName, arrayName ) {

       		setTimeout(function(){

					var textFieldID = "#"+textFieldName;
       				var listID = "#"+listName;

					var value = this.$(textFieldID).val();

					if (value != "") {

						$('<li id="deletableCells" style="white-space:normal;">').append(value).appendTo(this.$(listID));
						this.$(textFieldID).val('');
						this.$(listID).listview("refresh");

						ProgressData.addItemToList(arrayName, value);
					}
			}, 200);
       	},

		reachingActivityGoalsFieldSetChanged: function() {

			var reachingActivityGoals = this.$("#reachingActivityGoalsFieldSet input:checked").val();
			ProgressData.set("reachingActivityGoals" + this.guideNum, reachingActivityGoals);
			ProgressData.save();
		},

		reachingDietGoalsFieldSetChanged: function() {

			var reachingDietGoals = this.$("#reachingDietGoalsFieldSet input:checked").val();
			ProgressData.set("reachingDietGoals" + this.guideNum, reachingDietGoals);
			ProgressData.save();
		},

		getIndexAndRemove: function (ev, arrayName) {

			var selectedIndex = $(ev.currentTarget).index();
			var titleString = "Are you sure you want to delete " + $(ev.currentTarget).text();

			function onConfirm(buttonIndex) {
  				if (buttonIndex === 1) {

					//this accounts for the radio buttons in cell 0 and for the odd way that JQuery returns indexes starting at 1 instead of 0
					//if (arrayName === "activityGoalChanges" || arrayName === "dietGoalChanges") {
					if (arrayName.indexOf ("activityGoalChanges") > -1 || arrayName.indexOf("dietGoalChanges") > -1) {
						selectedIndex = selectedIndex-2;
					} else {
						selectedIndex = selectedIndex-1;
					}

					var success = false;
					success = ProgressData.removeItemFromList(arrayName, selectedIndex);

					if (success) {
						$(ev.currentTarget).remove();
					}
				}
			}

			if ( typeof navigator.notification == 'undefined') {
				if (confirm(titleString)) onConfirm(1);
			} else {
				navigator.notification.confirm(
					' ', // message
					onConfirm,            // callback to invoke with index of button pressed
					titleString,           // title
					['Yes','No']     // buttonLabels
				);
			}
		}
    });

    return ProgressReviewView;
});
