define(function(require) {
    var log = require("loglevel"),
        Handlebars = require("handlebars"),
        template = require("text!templates/summaryChecklist.html"),
        UserData = require("models/UserData");

    var compiled_template = Handlebars.compile(template);

    var curWt = 0.0;


    var handoutTap = false;
    var chapterTap = false;
//

	var chapterComplete;
    var handoutComplete;

    var rateValue = 0.5;
    var rateText = "";
    var mcaValue = 0;

    var percentToLose = 0.0;
    var targetWeight = 0.0;
    var poundsToLose = 0.0;

    var guideNumber;

    if(UserData.get('mcaValue')){
    	mcaValue = UserData.get('mcaValue');
    }

    var mcaText = "";
    var calorieGoalValue = 1200;
    var calorieGoalText = "";
    var dateGoalReached = new Date();

	var SummaryChecklistView = Backbone.View.extend({
        id: "summaryChecklistView",
        guideId: "",

        templateName: "summaryChecklist.html",

           events: {

              "change #completedChapters": "chapterTapped",
              "change #readHandouts": "handoutTapped",
              "click #calorieRange": "calRangeTapped"
//

           },

		initialize: function(args) {
			console.log ("initializing userInfo view: " + this);

			guideNumber = args.guide;

		},

		render: function() {
			log.debug ("calling render in userInfo view with template name: " + this.templateName);

            this.$el.html(compiled_template(this.model.toJSON()));

            guideNumber = Number(guideNumber);

            handoutTap = false;
            chapterTap = false;

            if(UserData.get("guideChapterComplete")){
            	chapterComplete = UserData.get("guideChapterComplete");

            	if(chapterComplete[guideNumber - 1] === true){
            		chapterTap = true;
            		this.$('#completedChapters').replaceWith('<input type="checkbox" name="completedChapters" id="completedChapters" value="Completed All Chapters?" checked="checked" />');
            	}else{
            		chapterComplete[guideNumber -1] = false;
            		UserData.set("guideChapterComplete", chapterComplete);
            	}

            }

            if(UserData.get("guideHandoutComplete")){

            	handoutComplete = UserData.get("guideHandoutComplete");

            	if(handoutComplete[guideNumber - 1] === true){
            		handoutTap = true;
            		this.$('#readHandouts').replaceWith('<input type="checkbox" name="readHandouts" id="readHandouts" value="Read key Handouts/Links?" checked="checked" />');
            	}else{
            		handoutComplete[guideNumber -1] = false;
            		UserData.set("guideHandoutComplete", handoutComplete);
            	}
            }

            this.runCalcs();

            return this;
		},
		runCalcs: function(){
			console.log("Guide Number: " + guideNumber);

            UserData.set("currentGuide", undefined);

            if (!(UserData.get("currentWeight"))){
        		curWt = UserData.get("initialWeight");
        		UserData.set("currentWeight",curWt);
   		     }else{
        		curWt = UserData.get("currentWeight");
        	}

            if(!(UserData.get("initialWeightLossRange"))){
            	rateValue = 0.5;
            	UserData.set("initialWeightLossRange", rateValue);
            }else{
            	rateValue = UserData.get("initialWeightLossRange");
            }

            if(!(UserData.get("mcaValue"))){
            	mcaValue = 0;
            }else{
            	mcaValue = UserData.get("mcaValue");
            }

            calorieGoalValue = UserData.calculateCalorieGoal(rateValue,curWt);

            if(Number(UserData.get("mcaValue")) > 10 || Number(UserData.get("mcaValue")) < -10){
            	this.$('#mcaText').replaceWith('<p id="mcaText">Includes ' + mcaValue + ' Calorie adjustment</p>');
            	calorieGoalValue = Number(calorieGoalValue) + Number(mcaValue);
            	
            	// if(calorieGoalValue < 1200){
            		// calorieGoalValue = 1200;
            	// }
            	
            }else{
            	this.$('#mcaText').replaceWith('<p id="mcaText">Tap to adjust Calorie goal</p>');
            	UserData.set("mcaValue", mcaValue);
            }

            UserData.set("dailyCalorieGoal", calorieGoalValue);

            percentToLose = 5.0;

            if(UserData.get("initialPercentToLose")){
            	percentToLose = UserData.get("initialPercentToLose");
            }else{
            	UserData.set("initialPercentToLose", percentToLose);
            }

    	 	poundsToLose = Number(curWt) * (percentToLose / 100.0);

    		targetWeight = Number(curWt) - poundsToLose;

    		percentToLose = Number(percentToLose).toFixed(1);
			poundsToLose = Number(poundsToLose).toFixed(1);
			targetWeight = Number(targetWeight).toFixed(1);

            UserData.set("initialLBSToLose", poundsToLose);
             UserData.set("initialTargetWeight", targetWeight);


             // date calculations
			var numberOfDays = 0;

			if(rateValue > 0){
				numberOfDays = (Number(poundsToLose) / Number(rateValue)) * 7;
			}

			var targetDate = new Date();
			targetDate.setDate(targetDate.getDate() + numberOfDays);

			var dd = targetDate.getDate();
			var mm = targetDate.getMonth();
			var yyyy = targetDate.getFullYear();

			var months = ["January","February","March","April","May","June","July","August","September","October","November","December"];

			var dateString = months[mm] + " " + dd + ", " + yyyy;

             UserData.set("goalReachedDate", dateString);




 			this.$('#percentToLoseValue').replaceWith("<span id='percentToLoseValue'>" + percentToLose + "</span>");
 			this.$('#poundsToLoseValue').replaceWith("<span id='poundsToLoseValue'>" + poundsToLose + "</span>");
 			this.$('#targetWeightValue').replaceWith("<span id='targetWeightValue'>" + targetWeight + "</span>");
 			this.$('#dateGoalReached').replaceWith("<span id='dateGoalReached'>" + dateString + "</span>");

 			this.$('#currentWeightValue').replaceWith("<span id='currentWeightValue'>" + curWt + "</span>");
 			this.$('#weightLossRateValue').replaceWith('<span id="weightLossRateValue">' + rateValue + '</span>');
 			this.$('#dailyCalorieGoalValue').replaceWith('<span id="dailyCalorieGoalValue">' + calorieGoalValue + '</span>');

 			var guideIndex = Number(guideNumber) - 1;

			var guideSnapshot = [];

             if(UserData.get("guideSnap")){
             	var pulledSnap = UserData.get("guideSnap");

             	for(var i=0; i < pulledSnap.length; i++){
             		console.log(pulledSnap[i]);
             		guideSnapshot[i] = pulledSnap[i];
             	}

             	guideSnapshot[guideIndex] = {chComplete: chapterTap, handComplete: handoutTap, percentToLose: percentToLose, poundsToLose: poundsToLose, targetWeight: targetWeight, dateGoalReached: dateString, currentWeight: curWt, weightLossRate: rateValue, dailyCalorieGoal: calorieGoalValue, mcaValue: mcaValue};


             }else{
             	guideSnapshot[guideIndex] = {chComplete: chapterTap, handComplete: handoutTap, percentToLose: percentToLose, poundsToLose: poundsToLose, targetWeight: targetWeight, dateGoalReached: dateString, currentWeight: curWt, weightLossRate: rateValue, dailyCalorieGoal: calorieGoalValue, mcaValue: mcaValue};
             }

             	UserData.set("guideSnap", guideSnapshot);

             	UserData.save();
		},
		calRangeTapped: function(){
			UserData.set("currentGuide", guideNumber);

			UserData.save();
		},
		chapterTapped: function(){

			if(chapterTap){
				chapterTap = false;
			}else{
				chapterTap = true;
			}

			var guideIndex = Number(guideNumber) - 1;

			var chComp = [];

             if(UserData.get("guideChapterComplete")){
             	var pulledCh = UserData.get("guideChapterComplete");

             	for(var i=0; i < pulledCh.length; i++){
             		console.log(pulledCh[i]);
             		chComp[i] = pulledCh[i];
             	}

             	chComp[guideIndex] = chapterTap;


             }else{
             	chComp[guideIndex] = chapterTap;
             }

             	UserData.set("guideChapterComplete", chComp);

			UserData.save();

			this.runCalcs();
		},
		handoutTapped: function(){

 		if(handoutTap){
				handoutTap = false;
			}else{
				handoutTap = true;
			}

			var guideIndex = Number(guideNumber) - 1;

			var hoComp = [];

             if(UserData.get("guideHandoutComplete")){
             	var pulledHo = UserData.get("guideHandoutComplete");

             	for(var i=0; i < pulledHo.length; i++){
             		console.log(pulledHo[i]);
             		hoComp[i] = pulledHo[i];
             	}

             	hoComp[guideIndex] = handoutTap;

             }else{
             	hoComp[guideIndex] = handoutTap;
             }

            UserData.set("guideHandoutComplete", hoComp);

			UserData.save();

			this.runCalcs();

		},
		weightLossRateSelect: function(){
			// var rateValue = prompt('Enter the rate at which you would like to lose weight (lbs. per week)');

			// calorie calculations
			var baselineWeight = UserData.get("initialWeight");

			var minGoal = 1200;
   			 var maxGoal = 3500;
   			 var goalCal = 1200;

 			   var currentWeight = Number(baselineWeight);
 		   // var lossRate = Number(rateValue);
//
    // var lossRate = UserData.get("initialWeightLossRange");
//
    if (currentWeight < 200) {
        minGoal = 1200;
        maxGoal = 1500;
        goalCal = minGoal + ((maxGoal - minGoal)*((lossRate-2)/(-2)));
    } else if (currentWeight < 226) {
        minGoal = 1500;
        maxGoal = 1800;
        goalCal = minGoal + ((maxGoal - minGoal)*((lossRate-2)/(-2)));
    } else if (currentWeight < 251) {
        minGoal = 1800;
        maxGoal = 2000;
        goalCal = minGoal + ((maxGoal - minGoal)*((lossRate-2)/(-2)));
    } else if (currentWeight < 301) {
        minGoal = 2000;
        maxGoal = 2500;
        goalCal = minGoal + ((maxGoal - minGoal)*((lossRate-2)/(-2)));
    } else if (currentWeight < 351) {
        minGoal = 2500;
        maxGoal = 3000;
        goalCal = minGoal + ((maxGoal - minGoal)*((lossRate-2)/(-2)));
    } else {
        minGoal = 3000;
        maxGoal = 3500;
        goalCal = minGoal + ((maxGoal - minGoal)*(lossRate/2));
    }

    if(UserData.get("mcaValue")){
    goalCal = Number(goalCal) + Number(UserData.get("mcaValue"));
    }

			this.$('#dailyCalorieGoalValue').html(goalCal);

			// date calculations
			var numberOfDays = Number(UserData.get("initialLBSToLose")) / rateValue;

			var targetDate = new Date();
			targetDate.setDate(targetDate.getDate() + numberOfDays);

			var dd = targetDate.getDate();
			var mm = targetDate.getMonth();
			var yyyy = targetDate.getFullYear();

			var months = ["January","February","March","April","May","June","July","August","September","October","November","December"];

			var dateString = months[mm] + " " + dd + ", " + yyyy;

			goalCal = Number(goalCal).toFixed(0);
			// set and save
			 UserData.set("initialWeightLossRange", rateValue);
             UserData.set("goalReachedDate", dateString);
             UserData.set("dailyCalorieGoal", goalCal);

             UserData.save();
		},
		adjustCaloriesSelect: function(){
			var adjustCaloriesValue = prompt('Enter the number of calories you would like to adjust your calorie goal by');
			var baselineWeight = UserData.get("initialWeight");

			var minGoal = 1200;
   			 var maxGoal = 3500;
   			 var goalCal = 1200;

 			   var currentWeight = Number(baselineWeight);
 		   var lossRate = Number(UserData.get("initialWeightLossRange"));

//
    // var lossRate = UserData.get("initialWeightLossRange");
//
    if (currentWeight < 200) {
        minGoal = 1200;
        maxGoal = 1500;
        goalCal = minGoal + ((maxGoal - minGoal)*((lossRate-2)/(-2)));
    } else if (currentWeight < 226) {
        minGoal = 1500;
        maxGoal = 1800;
        goalCal = minGoal + ((maxGoal - minGoal)*((lossRate-2)/(-2)));
    } else if (currentWeight < 251) {
        minGoal = 1800;
        maxGoal = 2000;
        goalCal = minGoal + ((maxGoal - minGoal)*((lossRate-2)/(-2)));
    } else if (currentWeight < 301) {
        minGoal = 2000;
        maxGoal = 2500;
        goalCal = minGoal + ((maxGoal - minGoal)*((lossRate-2)/(-2)));
    } else if (currentWeight < 351) {
        minGoal = 2500;
        maxGoal = 3000;
        goalCal = minGoal + ((maxGoal - minGoal)*((lossRate-2)/(-2)));
    } else {
        minGoal = 3000;
        maxGoal = 3500;
        goalCal = minGoal + ((maxGoal - minGoal)*(lossRate/2));
    }

    goalCal = Number(goalCal) + Number(adjustCaloriesValue);

			console.log("current Weight: " + currentWeight + " | loss Rate: " + lossRate + " | cal goal: " + goalCal + " | adjustvalue: " + adjustCaloriesValue);


			var mcaText = "Tap to set Medical Calorie Adjustment";

			if (adjustCaloriesValue !== 0){
				mcaText = "Includes Medical Calorie Adjustment of " + adjustCaloriesValue + " Calories";
			}

			goalCal = Number(goalCal).toFixed(0);

			UserData.set("mcaValue", adjustCaloriesValue);
             UserData.set("medicalCalorieAdjustmentText", mcaText);
             UserData.set("dailyCalorieGoal", goalCal);

             UserData.save();
		},
		calendarSelect: function(){
			// TODO: setup calendar functionality
		}

	});
	return SummaryChecklistView;
});
