define(function(require) {
    var log = require("loglevel"),
        Handlebars = require("handlebars"),
        UserData = require("models/UserData"),
        SurveyData = require("models/SurveyData"),
        Summary = require("models/GuideSummaryModel"),
        Guides = require("collections/allGuides"),
        template = require("text!templates/main-settings.html");

    // Compile the template once.
    var compiled_template = Handlebars.compile(template);

    // The view for all the flowers
    var SettingsView = Backbone.View.extend({
        // Set the id attribute on the div.
        id: "allSettingsView",

        events: {
        	'click #unlockGuides': 'unlockGuides',
            'click #deleteData': 'clearAllData',
            'click #test-data-button': 'populateTestData',
            'change #test-switch': 'saveSettingsData' // add more events with this function if necessary
        },

        render: function() {
            
            $(this.el).html(compiled_template(UserData.toJSON()));
            return this;
        },

        clearAllData: function() {
            // DON'T DO THIS!!!!
            // LocalStorage is shared between all apps.
            //localStorage.clear();

            // Clear the local UserData object...
            UserData.clear();
			SurveyData.clear();
			Guides.clear(); // Guides saves themselves
            // Save changes to local storage.
            UserData.save();
            SurveyData.save();
            alert("All App data has been reset.");
		},

		saveSettingsData: function() {
			var ts = $("#test-switch").val();
			console.log("test-switch val: " + ts );

			var sel = (ts === "on") ? "selected" : "";
			UserData.set("testingConfig", sel);
			UserData.save();

        },

        populateTestData: function() {
            this.$('#test-data-popup').popup({
                afterclose: function(event) {}
            });

            this.$("#test-data-popup #ok-button").one('click', function() {
                // Save test data to local storage by creating a UserData object with default data.
                UserData.reset();
                $('#test-data-popup').popup('close');
            });

            // Handle 'cancel' button click.
            this.$("#test-data-popup #cancel-button").one('click', function() {
                $('#test-data-popup').popup('close');
            });

            this.$('#test-data-popup').popup('open', {
                positionTo: 'window'
            });
        },
        
        unlockGuides: function() {
    		console.log ("UNLOCK THE GUIDES");
    	
    		//we can flesh this out to go thru and set the start and end dates to actual real dates
    		var now = new Date();
    		var summary, summaries;

    		Guides.each (function(guide) {
    			guide.save("status", "check");
				// create a summary for each guide
             	summaries = guide.get("summaries");
	            summary = new Summary(guide.id, now);
	            summaries.unshift(summary.toJSON());
                guide.save("summaries", summaries);
    		});
    	
    	}
    });



    return SettingsView;
});
